/* mpris_client.c generated by valac 0.56.18-dirty, the Vala compiler
 * generated from mpris_client.vala, do not modify */

/*
 * This file is part of budgie-desktop
 *
 * Copyright Budgie Desktop Developers
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include "org.buddiesofbudgie.budgie-desktop.raven.widget.MediaControls.h"
#include <glib-object.h>
#include <glib.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	MPRIS_CLIENT_0_PROPERTY,
	MPRIS_CLIENT_PLAYER_PROPERTY,
	MPRIS_CLIENT_PROP_PROPERTY,
	MPRIS_CLIENT_NUM_PROPERTIES
};
static GParamSpec* mpris_client_properties[MPRIS_CLIENT_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	MPRIS_DBUS_IMPL_NAME_OWNER_CHANGED_SIGNAL,
	MPRIS_DBUS_IMPL_NAME_ACQUIRED_SIGNAL,
	MPRIS_DBUS_IMPL_NUM_SIGNALS
};
static guint mpris_dbus_impl_signals[MPRIS_DBUS_IMPL_NUM_SIGNALS] = {0};
typedef GDBusProxy MprisDBusImplProxy;
typedef GDBusProxyClass MprisDBusImplProxyClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _MprisDbusImplListNamesReadyData MprisDbusImplListNamesReadyData;
enum  {
	MPRIS_DBUS_PROP_IFACE_PROPERTIES_CHANGED_SIGNAL,
	MPRIS_DBUS_PROP_IFACE_NUM_SIGNALS
};
static guint mpris_dbus_prop_iface_signals[MPRIS_DBUS_PROP_IFACE_NUM_SIGNALS] = {0};
typedef GDBusProxy MprisDbusPropIfaceProxy;
typedef GDBusProxyClass MprisDbusPropIfaceProxyClass;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef GDBusProxy MprisIfaceProxy;
typedef GDBusProxyClass MprisIfaceProxyClass;
typedef struct _MprisIfaceRaiseReadyData MprisIfaceRaiseReadyData;
typedef struct _MprisIfaceQuitReadyData MprisIfaceQuitReadyData;
typedef GDBusProxy MprisPlayerIfaceProxy;
typedef GDBusProxyClass MprisPlayerIfaceProxyClass;
typedef struct _MprisPlayerIfaceNextReadyData MprisPlayerIfaceNextReadyData;
typedef struct _MprisPlayerIfacePreviousReadyData MprisPlayerIfacePreviousReadyData;
typedef struct _MprisPlayerIfacePauseReadyData MprisPlayerIfacePauseReadyData;
typedef struct _MprisPlayerIfacePlayPauseReadyData MprisPlayerIfacePlayPauseReadyData;
typedef struct _MprisPlayerIfaceStopReadyData MprisPlayerIfaceStopReadyData;
typedef struct _MprisPlayerIfacePlayReadyData MprisPlayerIfacePlayReadyData;
typedef struct _MprisPlayerIfaceSeekReadyData MprisPlayerIfaceSeekReadyData;
typedef struct _MprisPlayerIfaceOpenUriReadyData MprisPlayerIfaceOpenUriReadyData;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _NewIfaceData NewIfaceData;

struct _MprisClientPrivate {
	MprisPlayerIface* _player;
	MprisDbusPropIface* _prop;
};

struct _MprisDbusImplListNamesReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisIfaceRaiseReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisIfaceQuitReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisPlayerIfaceNextReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisPlayerIfacePreviousReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisPlayerIfacePauseReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisPlayerIfacePlayPauseReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisPlayerIfaceStopReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisPlayerIfacePlayReadyData {
	GDBusMethodInvocation* _invocation_;
};

struct _MprisPlayerIfaceSeekReadyData {
	GDBusMethodInvocation* _invocation_;
	gint64 offset;
};

struct _MprisPlayerIfaceOpenUriReadyData {
	GDBusMethodInvocation* _invocation_;
	gchar* uri;
};

struct _NewIfaceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	gchar* busname;
	MprisClient* result;
	MprisPlayerIface* play;
	MprisClient* cl;
	MprisDbusPropIface* prop;
	MprisPlayerIface* _tmp0_;
	MprisPlayerIface* _tmp1_;
	MprisPlayerIface* _tmp2_;
	GError* e;
	GError* _tmp3_;
	const gchar* _tmp4_;
	MprisDbusPropIface* _tmp5_;
	MprisDbusPropIface* _tmp6_;
	MprisDbusPropIface* _tmp7_;
	GError* _vala1_e;
	GError* _tmp8_;
	const gchar* _tmp9_;
	MprisPlayerIface* _tmp10_;
	MprisDbusPropIface* _tmp11_;
	MprisClient* _tmp12_;
	GError* _inner_error0_;
};

static gint MprisClient_private_offset;
static gpointer mpris_client_parent_class = NULL;
static GType mpris_client_type_id = 0;
static GType mpris_dbus_impl_type_id = 0;
static GType mpris_dbus_prop_iface_type_id = 0;
static GType mpris_iface_type_id = 0;
static GType mpris_player_iface_type_id = 0;

static void mpris_client_finalize (GObject * obj);
static void _vala_mpris_client_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec);
static void _vala_mpris_client_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec);
static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING (GClosure * closure,
                                                         GValue * return_value,
                                                         guint n_param_values,
                                                         const GValue * param_values,
                                                         gpointer invocation_hint,
                                                         gpointer marshal_data);
static void mpris_dbus_impl_proxy_g_signal (GDBusProxy* proxy,
                                     const gchar* sender_name,
                                     const gchar* signal_name,
                                     GVariant* parameters);
static void _dbus_handle_mpris_dbus_impl_name_owner_changed (MprisDBusImpl* self,
                                                      GVariant* parameters);
static void _dbus_handle_mpris_dbus_impl_name_acquired (MprisDBusImpl* self,
                                                 GVariant* parameters);
static void _vala_g_async_ready_callback (GObject *source_object,
                                   GAsyncResult *res,
                                   void *user_data);
static void mpris_dbus_impl_proxy_list_names_async (MprisDBusImpl* self,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
static gchar** mpris_dbus_impl_proxy_list_names_finish (MprisDBusImpl* self,
                                                 GAsyncResult* _res_,
                                                 gint* result_length1,
                                                 GError** error);
static void mpris_dbus_impl_proxy_mpris_dbus_impl_interface_init (MprisDBusImplIface* iface);
static void _dbus_mpris_dbus_impl_list_names (MprisDBusImpl* self,
                                       GVariant* _parameters_,
                                       GDBusMethodInvocation* invocation);
static void _dbus_mpris_dbus_impl_list_names_ready (GObject * source_object,
                                             GAsyncResult * _res_,
                                             gpointer _user_data_);
static void mpris_dbus_impl_dbus_interface_method_call (GDBusConnection* connection,
                                                 const gchar* sender,
                                                 const gchar* object_path,
                                                 const gchar* interface_name,
                                                 const gchar* method_name,
                                                 GVariant* parameters,
                                                 GDBusMethodInvocation* invocation,
                                                 gpointer user_data);
static GVariant* mpris_dbus_impl_dbus_interface_get_property (GDBusConnection* connection,
                                                       const gchar* sender,
                                                       const gchar* object_path,
                                                       const gchar* interface_name,
                                                       const gchar* property_name,
                                                       GError** error,
                                                       gpointer user_data);
static gboolean mpris_dbus_impl_dbus_interface_set_property (GDBusConnection* connection,
                                                      const gchar* sender,
                                                      const gchar* object_path,
                                                      const gchar* interface_name,
                                                      const gchar* property_name,
                                                      GVariant* value,
                                                      GError** error,
                                                      gpointer user_data);
static void _dbus_mpris_dbus_impl_name_owner_changed (GObject* _sender,
                                               const gchar* name,
                                               const gchar* old_owner,
                                               const gchar* new_owner,
                                               gpointer* _data);
static void _dbus_mpris_dbus_impl_name_acquired (GObject* _sender,
                                          const gchar* name,
                                          gpointer* _data);
static void _mpris_dbus_impl_unregister_object (gpointer user_data);
static void g_cclosure_user_marshal_VOID__STRING_BOXED_BOXED_INT (GClosure * closure,
                                                           GValue * return_value,
                                                           guint n_param_values,
                                                           const GValue * param_values,
                                                           gpointer invocation_hint,
                                                           gpointer marshal_data);
static void mpris_dbus_prop_iface_proxy_g_signal (GDBusProxy* proxy,
                                           const gchar* sender_name,
                                           const gchar* signal_name,
                                           GVariant* parameters);
static void _dbus_handle_mpris_dbus_prop_iface_properties_changed (MprisDbusPropIface* self,
                                                            GVariant* parameters);
static void mpris_dbus_prop_iface_proxy_mpris_dbus_prop_iface_interface_init (MprisDbusPropIfaceIface* iface);
static void mpris_dbus_prop_iface_dbus_interface_method_call (GDBusConnection* connection,
                                                       const gchar* sender,
                                                       const gchar* object_path,
                                                       const gchar* interface_name,
                                                       const gchar* method_name,
                                                       GVariant* parameters,
                                                       GDBusMethodInvocation* invocation,
                                                       gpointer user_data);
static GVariant* mpris_dbus_prop_iface_dbus_interface_get_property (GDBusConnection* connection,
                                                             const gchar* sender,
                                                             const gchar* object_path,
                                                             const gchar* interface_name,
                                                             const gchar* property_name,
                                                             GError** error,
                                                             gpointer user_data);
static gboolean mpris_dbus_prop_iface_dbus_interface_set_property (GDBusConnection* connection,
                                                            const gchar* sender,
                                                            const gchar* object_path,
                                                            const gchar* interface_name,
                                                            const gchar* property_name,
                                                            GVariant* value,
                                                            GError** error,
                                                            gpointer user_data);
static void _dbus_mpris_dbus_prop_iface_properties_changed (GObject* _sender,
                                                     const gchar* iface,
                                                     GHashTable* changed,
                                                     gchar** invalid,
                                                     gint invalid_length1,
                                                     gpointer* _data);
static void _mpris_dbus_prop_iface_unregister_object (gpointer user_data);
static void mpris_iface_proxy_g_signal (GDBusProxy* proxy,
                                 const gchar* sender_name,
                                 const gchar* signal_name,
                                 GVariant* parameters);
static void mpris_iface_proxy_raise_async (MprisIface* self,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_);
static void mpris_iface_proxy_raise_finish (MprisIface* self,
                                     GAsyncResult* _res_,
                                     GError** error);
static void mpris_iface_proxy_quit_async (MprisIface* self,
                                   GAsyncReadyCallback _callback_,
                                   gpointer _user_data_);
static void mpris_iface_proxy_quit_finish (MprisIface* self,
                                    GAsyncResult* _res_,
                                    GError** error);
static gboolean mpris_iface_dbus_proxy_get_can_quit (MprisIface* self);
static void mpris_iface_dbus_proxy_set_can_quit (MprisIface* self,
                                          gboolean value);
static gboolean mpris_iface_dbus_proxy_get_fullscreen (MprisIface* self);
static gboolean mpris_iface_dbus_proxy_get_can_set_fullscreen (MprisIface* self);
static gboolean mpris_iface_dbus_proxy_get_can_raise (MprisIface* self);
static gboolean mpris_iface_dbus_proxy_get_has_track_list (MprisIface* self);
static gchar* mpris_iface_dbus_proxy_get_identity (MprisIface* self);
static gchar* mpris_iface_dbus_proxy_get_desktop_entry (MprisIface* self);
static gchar** mpris_iface_dbus_proxy_get_supported_uri_schemes (MprisIface* self,
                                                          gint* result_length1);
static gchar** mpris_iface_dbus_proxy_get_supported_mime_types (MprisIface* self,
                                                         gint* result_length1);
static void mpris_iface_proxy_mpris_iface_interface_init (MprisIfaceIface* iface);
static void _dbus_mpris_iface_raise (MprisIface* self,
                              GVariant* _parameters_,
                              GDBusMethodInvocation* invocation);
static void _dbus_mpris_iface_raise_ready (GObject * source_object,
                                    GAsyncResult * _res_,
                                    gpointer _user_data_);
static void _dbus_mpris_iface_quit (MprisIface* self,
                             GVariant* _parameters_,
                             GDBusMethodInvocation* invocation);
static void _dbus_mpris_iface_quit_ready (GObject * source_object,
                                   GAsyncResult * _res_,
                                   gpointer _user_data_);
static void mpris_iface_dbus_interface_method_call (GDBusConnection* connection,
                                             const gchar* sender,
                                             const gchar* object_path,
                                             const gchar* interface_name,
                                             const gchar* method_name,
                                             GVariant* parameters,
                                             GDBusMethodInvocation* invocation,
                                             gpointer user_data);
static GVariant* mpris_iface_dbus_interface_get_property (GDBusConnection* connection,
                                                   const gchar* sender,
                                                   const gchar* object_path,
                                                   const gchar* interface_name,
                                                   const gchar* property_name,
                                                   GError** error,
                                                   gpointer user_data);
static GVariant* _dbus_mpris_iface_get_can_quit (MprisIface* self);
static GVariant* _dbus_mpris_iface_get_fullscreen (MprisIface* self);
static GVariant* _dbus_mpris_iface_get_can_set_fullscreen (MprisIface* self);
static GVariant* _dbus_mpris_iface_get_can_raise (MprisIface* self);
static GVariant* _dbus_mpris_iface_get_has_track_list (MprisIface* self);
static GVariant* _dbus_mpris_iface_get_identity (MprisIface* self);
static GVariant* _dbus_mpris_iface_get_desktop_entry (MprisIface* self);
static GVariant* _dbus_mpris_iface_get_supported_uri_schemes (MprisIface* self);
static GVariant* _dbus_mpris_iface_get_supported_mime_types (MprisIface* self);
static gboolean mpris_iface_dbus_interface_set_property (GDBusConnection* connection,
                                                  const gchar* sender,
                                                  const gchar* object_path,
                                                  const gchar* interface_name,
                                                  const gchar* property_name,
                                                  GVariant* value,
                                                  GError** error,
                                                  gpointer user_data);
static void _dbus_mpris_iface_set_can_quit (MprisIface* self,
                                     GVariant* _value);
static void _mpris_iface_unregister_object (gpointer user_data);
static void mpris_player_iface_proxy_g_signal (GDBusProxy* proxy,
                                        const gchar* sender_name,
                                        const gchar* signal_name,
                                        GVariant* parameters);
static void mpris_player_iface_proxy_raise_async (MprisIface* self,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
static void mpris_player_iface_proxy_raise_finish (MprisIface* self,
                                            GAsyncResult* _res_,
                                            GError** error);
static void mpris_player_iface_proxy_quit_async (MprisIface* self,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
static void mpris_player_iface_proxy_quit_finish (MprisIface* self,
                                           GAsyncResult* _res_,
                                           GError** error);
static gboolean mpris_player_iface_dbus_proxy_get_can_quit (MprisIface* self);
static void mpris_player_iface_dbus_proxy_set_can_quit (MprisIface* self,
                                                 gboolean value);
static gboolean mpris_player_iface_dbus_proxy_get_fullscreen (MprisIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_can_set_fullscreen (MprisIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_can_raise (MprisIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_has_track_list (MprisIface* self);
static gchar* mpris_player_iface_dbus_proxy_get_identity (MprisIface* self);
static gchar* mpris_player_iface_dbus_proxy_get_desktop_entry (MprisIface* self);
static gchar** mpris_player_iface_dbus_proxy_get_supported_uri_schemes (MprisIface* self,
                                                                 gint* result_length1);
static gchar** mpris_player_iface_dbus_proxy_get_supported_mime_types (MprisIface* self,
                                                                gint* result_length1);
static void mpris_player_iface_proxy_mpris_iface_interface_init (MprisIfaceIface* iface);
static void mpris_player_iface_proxy_next_async (MprisPlayerIface* self,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
static void mpris_player_iface_proxy_next_finish (MprisPlayerIface* self,
                                           GAsyncResult* _res_,
                                           GError** error);
static void mpris_player_iface_proxy_previous_async (MprisPlayerIface* self,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
static void mpris_player_iface_proxy_previous_finish (MprisPlayerIface* self,
                                               GAsyncResult* _res_,
                                               GError** error);
static void mpris_player_iface_proxy_pause_async (MprisPlayerIface* self,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
static void mpris_player_iface_proxy_pause_finish (MprisPlayerIface* self,
                                            GAsyncResult* _res_,
                                            GError** error);
static void mpris_player_iface_proxy_play_pause_async (MprisPlayerIface* self,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
static void mpris_player_iface_proxy_play_pause_finish (MprisPlayerIface* self,
                                                 GAsyncResult* _res_,
                                                 GError** error);
static void mpris_player_iface_proxy_stop_async (MprisPlayerIface* self,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
static void mpris_player_iface_proxy_stop_finish (MprisPlayerIface* self,
                                           GAsyncResult* _res_,
                                           GError** error);
static void mpris_player_iface_proxy_play_async (MprisPlayerIface* self,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
static void mpris_player_iface_proxy_play_finish (MprisPlayerIface* self,
                                           GAsyncResult* _res_,
                                           GError** error);
static void mpris_player_iface_proxy_seek_async (MprisPlayerIface* self,
                                          gint64 offset,
                                          GAsyncReadyCallback _callback_,
                                          gpointer _user_data_);
static void mpris_player_iface_proxy_seek_finish (MprisPlayerIface* self,
                                           GAsyncResult* _res_,
                                           GError** error);
static void mpris_player_iface_proxy_open_uri_async (MprisPlayerIface* self,
                                              const gchar* uri,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
static void mpris_player_iface_proxy_open_uri_finish (MprisPlayerIface* self,
                                               GAsyncResult* _res_,
                                               GError** error);
static gchar* mpris_player_iface_dbus_proxy_get_playback_status (MprisPlayerIface* self);
static gchar* mpris_player_iface_dbus_proxy_get_loop_status (MprisPlayerIface* self);
static void mpris_player_iface_dbus_proxy_set_loop_status (MprisPlayerIface* self,
                                                    const gchar* value);
static gdouble mpris_player_iface_dbus_proxy_get_rate (MprisPlayerIface* self);
static void mpris_player_iface_dbus_proxy_set_rate (MprisPlayerIface* self,
                                             gdouble value);
static gboolean mpris_player_iface_dbus_proxy_get_shuffle (MprisPlayerIface* self);
static void mpris_player_iface_dbus_proxy_set_shuffle (MprisPlayerIface* self,
                                                gboolean value);
static GHashTable* mpris_player_iface_dbus_proxy_get_metadata (MprisPlayerIface* self);
static gdouble mpris_player_iface_dbus_proxy_get_volume (MprisPlayerIface* self);
static void mpris_player_iface_dbus_proxy_set_volume (MprisPlayerIface* self,
                                               gdouble value);
static gint64 mpris_player_iface_dbus_proxy_get_position (MprisPlayerIface* self);
static gdouble mpris_player_iface_dbus_proxy_get_minimum_rate (MprisPlayerIface* self);
static gdouble mpris_player_iface_dbus_proxy_get_maximum_rate (MprisPlayerIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_can_go_next (MprisPlayerIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_can_go_previous (MprisPlayerIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_can_play (MprisPlayerIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_can_pause (MprisPlayerIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_can_seek (MprisPlayerIface* self);
static gboolean mpris_player_iface_dbus_proxy_get_can_control (MprisPlayerIface* self);
static void mpris_player_iface_proxy_mpris_player_iface_interface_init (MprisPlayerIfaceIface* iface);
static void _dbus_mpris_player_iface_next (MprisPlayerIface* self,
                                    GVariant* _parameters_,
                                    GDBusMethodInvocation* invocation);
static void _dbus_mpris_player_iface_next_ready (GObject * source_object,
                                          GAsyncResult * _res_,
                                          gpointer _user_data_);
static void _dbus_mpris_player_iface_previous (MprisPlayerIface* self,
                                        GVariant* _parameters_,
                                        GDBusMethodInvocation* invocation);
static void _dbus_mpris_player_iface_previous_ready (GObject * source_object,
                                              GAsyncResult * _res_,
                                              gpointer _user_data_);
static void _dbus_mpris_player_iface_pause (MprisPlayerIface* self,
                                     GVariant* _parameters_,
                                     GDBusMethodInvocation* invocation);
static void _dbus_mpris_player_iface_pause_ready (GObject * source_object,
                                           GAsyncResult * _res_,
                                           gpointer _user_data_);
static void _dbus_mpris_player_iface_play_pause (MprisPlayerIface* self,
                                          GVariant* _parameters_,
                                          GDBusMethodInvocation* invocation);
static void _dbus_mpris_player_iface_play_pause_ready (GObject * source_object,
                                                GAsyncResult * _res_,
                                                gpointer _user_data_);
static void _dbus_mpris_player_iface_stop (MprisPlayerIface* self,
                                    GVariant* _parameters_,
                                    GDBusMethodInvocation* invocation);
static void _dbus_mpris_player_iface_stop_ready (GObject * source_object,
                                          GAsyncResult * _res_,
                                          gpointer _user_data_);
static void _dbus_mpris_player_iface_play (MprisPlayerIface* self,
                                    GVariant* _parameters_,
                                    GDBusMethodInvocation* invocation);
static void _dbus_mpris_player_iface_play_ready (GObject * source_object,
                                          GAsyncResult * _res_,
                                          gpointer _user_data_);
static void _dbus_mpris_player_iface_seek (MprisPlayerIface* self,
                                    GVariant* _parameters_,
                                    GDBusMethodInvocation* invocation);
static void _dbus_mpris_player_iface_seek_ready (GObject * source_object,
                                          GAsyncResult * _res_,
                                          gpointer _user_data_);
static void _dbus_mpris_player_iface_open_uri (MprisPlayerIface* self,
                                        GVariant* _parameters_,
                                        GDBusMethodInvocation* invocation);
static void _dbus_mpris_player_iface_open_uri_ready (GObject * source_object,
                                              GAsyncResult * _res_,
                                              gpointer _user_data_);
static void mpris_player_iface_dbus_interface_method_call (GDBusConnection* connection,
                                                    const gchar* sender,
                                                    const gchar* object_path,
                                                    const gchar* interface_name,
                                                    const gchar* method_name,
                                                    GVariant* parameters,
                                                    GDBusMethodInvocation* invocation,
                                                    gpointer user_data);
static GVariant* mpris_player_iface_dbus_interface_get_property (GDBusConnection* connection,
                                                          const gchar* sender,
                                                          const gchar* object_path,
                                                          const gchar* interface_name,
                                                          const gchar* property_name,
                                                          GError** error,
                                                          gpointer user_data);
static GVariant* _dbus_mpris_player_iface_get_playback_status (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_loop_status (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_rate (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_shuffle (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_metadata (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_volume (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_position (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_minimum_rate (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_maximum_rate (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_can_go_next (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_can_go_previous (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_can_play (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_can_pause (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_can_seek (MprisPlayerIface* self);
static GVariant* _dbus_mpris_player_iface_get_can_control (MprisPlayerIface* self);
static gboolean mpris_player_iface_dbus_interface_set_property (GDBusConnection* connection,
                                                         const gchar* sender,
                                                         const gchar* object_path,
                                                         const gchar* interface_name,
                                                         const gchar* property_name,
                                                         GVariant* value,
                                                         GError** error,
                                                         gpointer user_data);
static void _dbus_mpris_player_iface_set_loop_status (MprisPlayerIface* self,
                                               GVariant* _value);
static void _dbus_mpris_player_iface_set_rate (MprisPlayerIface* self,
                                        GVariant* _value);
static void _dbus_mpris_player_iface_set_shuffle (MprisPlayerIface* self,
                                           GVariant* _value);
static void _dbus_mpris_player_iface_set_volume (MprisPlayerIface* self,
                                          GVariant* _value);
static void _mpris_player_iface_unregister_object (gpointer user_data);
static void new_iface_data_free (gpointer _data);
static gboolean new_iface_co (NewIfaceData* _data_);
static void new_iface_ready (GObject* source_object,
                      GAsyncResult* _res_,
                      gpointer _user_data_);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static const GDBusArgInfo _mpris_dbus_impl_dbus_arg_info_list_names_result = {-1, "result", "as", NULL};
static const GDBusArgInfo * const _mpris_dbus_impl_dbus_arg_info_list_names_in[] = {NULL};
static const GDBusArgInfo * const _mpris_dbus_impl_dbus_arg_info_list_names_out[] = {&_mpris_dbus_impl_dbus_arg_info_list_names_result, NULL};
static const GDBusMethodInfo _mpris_dbus_impl_dbus_method_info_list_names = {-1, "ListNames", (GDBusArgInfo **) (&_mpris_dbus_impl_dbus_arg_info_list_names_in), (GDBusArgInfo **) (&_mpris_dbus_impl_dbus_arg_info_list_names_out), NULL};
static const GDBusMethodInfo * const _mpris_dbus_impl_dbus_method_info[] = {&_mpris_dbus_impl_dbus_method_info_list_names, NULL};
static const GDBusArgInfo _mpris_dbus_impl_dbus_arg_info_name_owner_changed_name = {-1, "name", "s", NULL};
static const GDBusArgInfo _mpris_dbus_impl_dbus_arg_info_name_owner_changed_old_owner = {-1, "old_owner", "s", NULL};
static const GDBusArgInfo _mpris_dbus_impl_dbus_arg_info_name_owner_changed_new_owner = {-1, "new_owner", "s", NULL};
static const GDBusArgInfo * const _mpris_dbus_impl_dbus_arg_info_name_owner_changed[] = {&_mpris_dbus_impl_dbus_arg_info_name_owner_changed_name, &_mpris_dbus_impl_dbus_arg_info_name_owner_changed_old_owner, &_mpris_dbus_impl_dbus_arg_info_name_owner_changed_new_owner, NULL};
static const GDBusSignalInfo _mpris_dbus_impl_dbus_signal_info_name_owner_changed = {-1, "NameOwnerChanged", (GDBusArgInfo **) (&_mpris_dbus_impl_dbus_arg_info_name_owner_changed), NULL};
static const GDBusArgInfo _mpris_dbus_impl_dbus_arg_info_name_acquired_name = {-1, "name", "s", NULL};
static const GDBusArgInfo * const _mpris_dbus_impl_dbus_arg_info_name_acquired[] = {&_mpris_dbus_impl_dbus_arg_info_name_acquired_name, NULL};
static const GDBusSignalInfo _mpris_dbus_impl_dbus_signal_info_name_acquired = {-1, "NameAcquired", (GDBusArgInfo **) (&_mpris_dbus_impl_dbus_arg_info_name_acquired), NULL};
static const GDBusSignalInfo * const _mpris_dbus_impl_dbus_signal_info[] = {&_mpris_dbus_impl_dbus_signal_info_name_owner_changed, &_mpris_dbus_impl_dbus_signal_info_name_acquired, NULL};
static const GDBusPropertyInfo * const _mpris_dbus_impl_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _mpris_dbus_impl_dbus_interface_info = {-1, "org.freedesktop.DBus", (GDBusMethodInfo **) (&_mpris_dbus_impl_dbus_method_info), (GDBusSignalInfo **) (&_mpris_dbus_impl_dbus_signal_info), (GDBusPropertyInfo **) (&_mpris_dbus_impl_dbus_property_info), NULL};
static const GDBusInterfaceVTable _mpris_dbus_impl_dbus_interface_vtable = {mpris_dbus_impl_dbus_interface_method_call, mpris_dbus_impl_dbus_interface_get_property, mpris_dbus_impl_dbus_interface_set_property};
static const GDBusMethodInfo * const _mpris_dbus_prop_iface_dbus_method_info[] = {NULL};
static const GDBusArgInfo _mpris_dbus_prop_iface_dbus_arg_info_properties_changed_iface = {-1, "iface", "s", NULL};
static const GDBusArgInfo _mpris_dbus_prop_iface_dbus_arg_info_properties_changed_changed = {-1, "changed", "a{sv}", NULL};
static const GDBusArgInfo _mpris_dbus_prop_iface_dbus_arg_info_properties_changed_invalid = {-1, "invalid", "as", NULL};
static const GDBusArgInfo * const _mpris_dbus_prop_iface_dbus_arg_info_properties_changed[] = {&_mpris_dbus_prop_iface_dbus_arg_info_properties_changed_iface, &_mpris_dbus_prop_iface_dbus_arg_info_properties_changed_changed, &_mpris_dbus_prop_iface_dbus_arg_info_properties_changed_invalid, NULL};
static const GDBusSignalInfo _mpris_dbus_prop_iface_dbus_signal_info_properties_changed = {-1, "PropertiesChanged", (GDBusArgInfo **) (&_mpris_dbus_prop_iface_dbus_arg_info_properties_changed), NULL};
static const GDBusSignalInfo * const _mpris_dbus_prop_iface_dbus_signal_info[] = {&_mpris_dbus_prop_iface_dbus_signal_info_properties_changed, NULL};
static const GDBusPropertyInfo * const _mpris_dbus_prop_iface_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _mpris_dbus_prop_iface_dbus_interface_info = {-1, "org.freedesktop.DBus.Properties", (GDBusMethodInfo **) (&_mpris_dbus_prop_iface_dbus_method_info), (GDBusSignalInfo **) (&_mpris_dbus_prop_iface_dbus_signal_info), (GDBusPropertyInfo **) (&_mpris_dbus_prop_iface_dbus_property_info), NULL};
static const GDBusInterfaceVTable _mpris_dbus_prop_iface_dbus_interface_vtable = {mpris_dbus_prop_iface_dbus_interface_method_call, mpris_dbus_prop_iface_dbus_interface_get_property, mpris_dbus_prop_iface_dbus_interface_set_property};
static const GDBusArgInfo * const _mpris_iface_dbus_arg_info_raise_in[] = {NULL};
static const GDBusArgInfo * const _mpris_iface_dbus_arg_info_raise_out[] = {NULL};
static const GDBusMethodInfo _mpris_iface_dbus_method_info_raise = {-1, "Raise", (GDBusArgInfo **) (&_mpris_iface_dbus_arg_info_raise_in), (GDBusArgInfo **) (&_mpris_iface_dbus_arg_info_raise_out), NULL};
static const GDBusArgInfo * const _mpris_iface_dbus_arg_info_quit_in[] = {NULL};
static const GDBusArgInfo * const _mpris_iface_dbus_arg_info_quit_out[] = {NULL};
static const GDBusMethodInfo _mpris_iface_dbus_method_info_quit = {-1, "Quit", (GDBusArgInfo **) (&_mpris_iface_dbus_arg_info_quit_in), (GDBusArgInfo **) (&_mpris_iface_dbus_arg_info_quit_out), NULL};
static const GDBusMethodInfo * const _mpris_iface_dbus_method_info[] = {&_mpris_iface_dbus_method_info_raise, &_mpris_iface_dbus_method_info_quit, NULL};
static const GDBusSignalInfo * const _mpris_iface_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_can_quit = {-1, "CanQuit", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_fullscreen = {-1, "Fullscreen", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_can_set_fullscreen = {-1, "CanSetFullscreen", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_can_raise = {-1, "CanRaise", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_has_track_list = {-1, "HasTrackList", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_identity = {-1, "Identity", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_desktop_entry = {-1, "DesktopEntry", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_supported_uri_schemes = {-1, "SupportedUriSchemes", "as", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_iface_dbus_property_info_supported_mime_types = {-1, "SupportedMimeTypes", "as", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo * const _mpris_iface_dbus_property_info[] = {&_mpris_iface_dbus_property_info_can_quit, &_mpris_iface_dbus_property_info_fullscreen, &_mpris_iface_dbus_property_info_can_set_fullscreen, &_mpris_iface_dbus_property_info_can_raise, &_mpris_iface_dbus_property_info_has_track_list, &_mpris_iface_dbus_property_info_identity, &_mpris_iface_dbus_property_info_desktop_entry, &_mpris_iface_dbus_property_info_supported_uri_schemes, &_mpris_iface_dbus_property_info_supported_mime_types, NULL};
static const GDBusInterfaceInfo _mpris_iface_dbus_interface_info = {-1, "org.mpris.MediaPlayer2", (GDBusMethodInfo **) (&_mpris_iface_dbus_method_info), (GDBusSignalInfo **) (&_mpris_iface_dbus_signal_info), (GDBusPropertyInfo **) (&_mpris_iface_dbus_property_info), NULL};
static const GDBusInterfaceVTable _mpris_iface_dbus_interface_vtable = {mpris_iface_dbus_interface_method_call, mpris_iface_dbus_interface_get_property, mpris_iface_dbus_interface_set_property};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_next_in[] = {NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_next_out[] = {NULL};
static const GDBusMethodInfo _mpris_player_iface_dbus_method_info_next = {-1, "Next", (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_next_in), (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_next_out), NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_previous_in[] = {NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_previous_out[] = {NULL};
static const GDBusMethodInfo _mpris_player_iface_dbus_method_info_previous = {-1, "Previous", (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_previous_in), (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_previous_out), NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_pause_in[] = {NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_pause_out[] = {NULL};
static const GDBusMethodInfo _mpris_player_iface_dbus_method_info_pause = {-1, "Pause", (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_pause_in), (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_pause_out), NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_play_pause_in[] = {NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_play_pause_out[] = {NULL};
static const GDBusMethodInfo _mpris_player_iface_dbus_method_info_play_pause = {-1, "PlayPause", (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_play_pause_in), (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_play_pause_out), NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_stop_in[] = {NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_stop_out[] = {NULL};
static const GDBusMethodInfo _mpris_player_iface_dbus_method_info_stop = {-1, "Stop", (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_stop_in), (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_stop_out), NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_play_in[] = {NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_play_out[] = {NULL};
static const GDBusMethodInfo _mpris_player_iface_dbus_method_info_play = {-1, "Play", (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_play_in), (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_play_out), NULL};
static const GDBusArgInfo _mpris_player_iface_dbus_arg_info_seek_offset = {-1, "offset", "x", NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_seek_in[] = {&_mpris_player_iface_dbus_arg_info_seek_offset, NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_seek_out[] = {NULL};
static const GDBusMethodInfo _mpris_player_iface_dbus_method_info_seek = {-1, "Seek", (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_seek_in), (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_seek_out), NULL};
static const GDBusArgInfo _mpris_player_iface_dbus_arg_info_open_uri_uri = {-1, "uri", "s", NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_open_uri_in[] = {&_mpris_player_iface_dbus_arg_info_open_uri_uri, NULL};
static const GDBusArgInfo * const _mpris_player_iface_dbus_arg_info_open_uri_out[] = {NULL};
static const GDBusMethodInfo _mpris_player_iface_dbus_method_info_open_uri = {-1, "OpenUri", (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_open_uri_in), (GDBusArgInfo **) (&_mpris_player_iface_dbus_arg_info_open_uri_out), NULL};
static const GDBusMethodInfo * const _mpris_player_iface_dbus_method_info[] = {&_mpris_player_iface_dbus_method_info_next, &_mpris_player_iface_dbus_method_info_previous, &_mpris_player_iface_dbus_method_info_pause, &_mpris_player_iface_dbus_method_info_play_pause, &_mpris_player_iface_dbus_method_info_stop, &_mpris_player_iface_dbus_method_info_play, &_mpris_player_iface_dbus_method_info_seek, &_mpris_player_iface_dbus_method_info_open_uri, NULL};
static const GDBusSignalInfo * const _mpris_player_iface_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_playback_status = {-1, "PlaybackStatus", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_loop_status = {-1, "LoopStatus", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_rate = {-1, "Rate", "d", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_shuffle = {-1, "Shuffle", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_metadata = {-1, "Metadata", "a{sv}", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_volume = {-1, "Volume", "d", G_DBUS_PROPERTY_INFO_FLAGS_READABLE | G_DBUS_PROPERTY_INFO_FLAGS_WRITABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_position = {-1, "Position", "x", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_minimum_rate = {-1, "MinimumRate", "d", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_maximum_rate = {-1, "MaximumRate", "d", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_can_go_next = {-1, "CanGoNext", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_can_go_previous = {-1, "CanGoPrevious", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_can_play = {-1, "CanPlay", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_can_pause = {-1, "CanPause", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_can_seek = {-1, "CanSeek", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo _mpris_player_iface_dbus_property_info_can_control = {-1, "CanControl", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE, NULL};
static const GDBusPropertyInfo * const _mpris_player_iface_dbus_property_info[] = {&_mpris_player_iface_dbus_property_info_playback_status, &_mpris_player_iface_dbus_property_info_loop_status, &_mpris_player_iface_dbus_property_info_rate, &_mpris_player_iface_dbus_property_info_shuffle, &_mpris_player_iface_dbus_property_info_metadata, &_mpris_player_iface_dbus_property_info_volume, &_mpris_player_iface_dbus_property_info_position, &_mpris_player_iface_dbus_property_info_minimum_rate, &_mpris_player_iface_dbus_property_info_maximum_rate, &_mpris_player_iface_dbus_property_info_can_go_next, &_mpris_player_iface_dbus_property_info_can_go_previous, &_mpris_player_iface_dbus_property_info_can_play, &_mpris_player_iface_dbus_property_info_can_pause, &_mpris_player_iface_dbus_property_info_can_seek, &_mpris_player_iface_dbus_property_info_can_control, NULL};
static const GDBusInterfaceInfo _mpris_player_iface_dbus_interface_info = {-1, "org.mpris.MediaPlayer2.Player", (GDBusMethodInfo **) (&_mpris_player_iface_dbus_method_info), (GDBusSignalInfo **) (&_mpris_player_iface_dbus_signal_info), (GDBusPropertyInfo **) (&_mpris_player_iface_dbus_property_info), NULL};
static const GDBusInterfaceVTable _mpris_player_iface_dbus_interface_vtable = {mpris_player_iface_dbus_interface_method_call, mpris_player_iface_dbus_interface_get_property, mpris_player_iface_dbus_interface_set_property};

static inline gpointer
mpris_client_get_instance_private (MprisClient* self)
{
	return G_STRUCT_MEMBER_P (self, MprisClient_private_offset);
}

MprisClient*
mpris_client_construct (GType object_type,
                        MprisPlayerIface* player,
                        MprisDbusPropIface* prop)
{
	MprisClient * self = NULL;
	g_return_val_if_fail (player != NULL, NULL);
	g_return_val_if_fail (prop != NULL, NULL);
	self = (MprisClient*) g_object_new (object_type, "player", player, "prop", prop, NULL);
	return self;
}

MprisClient*
mpris_client_new (MprisPlayerIface* player,
                  MprisDbusPropIface* prop)
{
	return mpris_client_construct (TYPE_MPRIS_CLIENT, player, prop);
}

MprisPlayerIface*
mpris_client_get_player (MprisClient* self)
{
	MprisPlayerIface* result;
	MprisPlayerIface* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_player;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
mpris_client_set_player (MprisClient* self,
                         MprisPlayerIface* value)
{
	MprisPlayerIface* old_value;
	g_return_if_fail (self != NULL);
	old_value = mpris_client_get_player (self);
	if (old_value != value) {
		MprisPlayerIface* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_player);
		self->priv->_player = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, mpris_client_properties[MPRIS_CLIENT_PLAYER_PROPERTY]);
	}
}

MprisDbusPropIface*
mpris_client_get_prop (MprisClient* self)
{
	MprisDbusPropIface* result;
	MprisDbusPropIface* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_prop;
	result = _tmp0_;
	return result;
}

void
mpris_client_set_prop (MprisClient* self,
                       MprisDbusPropIface* value)
{
	MprisDbusPropIface* old_value;
	g_return_if_fail (self != NULL);
	old_value = mpris_client_get_prop (self);
	if (old_value != value) {
		MprisDbusPropIface* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_prop);
		self->priv->_prop = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, mpris_client_properties[MPRIS_CLIENT_PROP_PROPERTY]);
	}
}

static void
mpris_client_class_init (MprisClientClass * klass,
                         gpointer klass_data)
{
	mpris_client_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &MprisClient_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_mpris_client_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_mpris_client_set_property;
	G_OBJECT_CLASS (klass)->finalize = mpris_client_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), MPRIS_CLIENT_PLAYER_PROPERTY, mpris_client_properties[MPRIS_CLIENT_PLAYER_PROPERTY] = g_param_spec_object ("player", "player", "player", TYPE_MPRIS_PLAYER_IFACE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), MPRIS_CLIENT_PROP_PROPERTY, mpris_client_properties[MPRIS_CLIENT_PROP_PROPERTY] = g_param_spec_object ("prop", "prop", "prop", TYPE_MPRIS_DBUS_PROP_IFACE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}

static void
mpris_client_instance_init (MprisClient * self,
                            gpointer klass)
{
	self->priv = mpris_client_get_instance_private (self);
}

static void
mpris_client_finalize (GObject * obj)
{
	MprisClient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MPRIS_CLIENT, MprisClient);
	_g_object_unref0 (self->priv->_player);
	_g_object_unref0 (self->priv->_prop);
	G_OBJECT_CLASS (mpris_client_parent_class)->finalize (obj);
}

/**
 * Simple wrapper to ensure a lifetime reference to the encapsulated objects
 */
GType
mpris_client_get_type (void)
{
	return mpris_client_type_id;
}

GType
mpris_client_register_type (GTypeModule * module)
{
	static const GTypeInfo g_define_type_info = { sizeof (MprisClientClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) mpris_client_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MprisClient), 0, (GInstanceInitFunc) mpris_client_instance_init, NULL };
	mpris_client_type_id = g_type_module_register_type (module, G_TYPE_OBJECT, "MprisClient", &g_define_type_info, 0);
	MprisClient_private_offset = sizeof (MprisClientPrivate);
	return mpris_client_type_id;
}

static void
_vala_mpris_client_get_property (GObject * object,
                                 guint property_id,
                                 GValue * value,
                                 GParamSpec * pspec)
{
	MprisClient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_MPRIS_CLIENT, MprisClient);
	switch (property_id) {
		case MPRIS_CLIENT_PLAYER_PROPERTY:
		g_value_set_object (value, mpris_client_get_player (self));
		break;
		case MPRIS_CLIENT_PROP_PROPERTY:
		g_value_set_object (value, mpris_client_get_prop (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_mpris_client_set_property (GObject * object,
                                 guint property_id,
                                 const GValue * value,
                                 GParamSpec * pspec)
{
	MprisClient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_MPRIS_CLIENT, MprisClient);
	switch (property_id) {
		case MPRIS_CLIENT_PLAYER_PROPERTY:
		mpris_client_set_player (self, g_value_get_object (value));
		break;
		case MPRIS_CLIENT_PROP_PROPERTY:
		mpris_client_set_prop (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

void
mpris_dbus_impl_list_names (MprisDBusImpl* self,
                            GAsyncReadyCallback _callback_,
                            gpointer _user_data_)
{
	MprisDBusImplIface* _iface_;
	_iface_ = MPRIS_DBUS_IMPL_GET_INTERFACE (self);
	if (_iface_->list_names) {
		_iface_->list_names (self, _callback_, _user_data_);
	}
}

gchar**
mpris_dbus_impl_list_names_finish (MprisDBusImpl* self,
                                   GAsyncResult* _res_,
                                   gint* result_length1,
                                   GError** error)
{
	MprisDBusImplIface* _iface_;
	_iface_ = MPRIS_DBUS_IMPL_GET_INTERFACE (self);
	if (_iface_->list_names_finish) {
		return _iface_->list_names_finish (self, _res_, result_length1, error);
	}
	return NULL;
}

static void
g_cclosure_user_marshal_VOID__STRING_STRING_STRING (GClosure * closure,
                                                    GValue * return_value,
                                                    guint n_param_values,
                                                    const GValue * param_values,
                                                    gpointer invocation_hint,
                                                    gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING) (gpointer data1, const char* arg_1, const char* arg_2, const char* arg_3, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 4);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_string (param_values + 3), data2);
}

static void
mpris_dbus_impl_default_init (MprisDBusImplIface * iface,
                              gpointer iface_data)
{
	mpris_dbus_impl_signals[MPRIS_DBUS_IMPL_NAME_OWNER_CHANGED_SIGNAL] = g_signal_new ("name-owner-changed", TYPE_MPRIS_DBUS_IMPL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_STRING, G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
	mpris_dbus_impl_signals[MPRIS_DBUS_IMPL_NAME_ACQUIRED_SIGNAL] = g_signal_new ("name-acquired", TYPE_MPRIS_DBUS_IMPL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
}

/**
 * We need to probe the dbus daemon directly, hence this interface
 */
GType
mpris_dbus_impl_get_type (void)
{
	return mpris_dbus_impl_type_id;
}

GType
mpris_dbus_impl_register_type (GTypeModule * module)
{
	static const GTypeInfo g_define_type_info = { sizeof (MprisDBusImplIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) mpris_dbus_impl_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	mpris_dbus_impl_type_id = g_type_module_register_type (module, G_TYPE_INTERFACE, "MprisDBusImpl", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (mpris_dbus_impl_type_id, G_TYPE_OBJECT);
	g_type_set_qdata (mpris_dbus_impl_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) mpris_dbus_impl_proxy_get_type);
	g_type_set_qdata (mpris_dbus_impl_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.DBus");
	g_type_set_qdata (mpris_dbus_impl_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_mpris_dbus_impl_dbus_interface_info));
	g_type_set_qdata (mpris_dbus_impl_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) mpris_dbus_impl_register_object);
	return mpris_dbus_impl_type_id;
}

G_DEFINE_DYNAMIC_TYPE_EXTENDED (MprisDBusImplProxy, mpris_dbus_impl_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE_DYNAMIC (TYPE_MPRIS_DBUS_IMPL, mpris_dbus_impl_proxy_mpris_dbus_impl_interface_init) )
static void
mpris_dbus_impl_proxy_class_init (MprisDBusImplProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = mpris_dbus_impl_proxy_g_signal;
}

static void
_dbus_handle_mpris_dbus_impl_name_owner_changed (MprisDBusImpl* self,
                                                 GVariant* parameters)
{
	GVariantIter _arguments_iter;
	gchar* name = NULL;
	GVariant* _tmp0_;
	gchar* old_owner = NULL;
	GVariant* _tmp1_;
	gchar* new_owner = NULL;
	GVariant* _tmp2_;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp0_ = g_variant_iter_next_value (&_arguments_iter);
	name = g_variant_dup_string (_tmp0_, NULL);
	g_variant_unref (_tmp0_);
	_tmp1_ = g_variant_iter_next_value (&_arguments_iter);
	old_owner = g_variant_dup_string (_tmp1_, NULL);
	g_variant_unref (_tmp1_);
	_tmp2_ = g_variant_iter_next_value (&_arguments_iter);
	new_owner = g_variant_dup_string (_tmp2_, NULL);
	g_variant_unref (_tmp2_);
	g_signal_emit_by_name (self, "name-owner-changed", name, old_owner, new_owner);
	_g_free0 (name);
	_g_free0 (old_owner);
	_g_free0 (new_owner);
}

static void
_dbus_handle_mpris_dbus_impl_name_acquired (MprisDBusImpl* self,
                                            GVariant* parameters)
{
	GVariantIter _arguments_iter;
	gchar* name = NULL;
	GVariant* _tmp3_;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp3_ = g_variant_iter_next_value (&_arguments_iter);
	name = g_variant_dup_string (_tmp3_, NULL);
	g_variant_unref (_tmp3_);
	g_signal_emit_by_name (self, "name-acquired", name);
	_g_free0 (name);
}

static void
mpris_dbus_impl_proxy_g_signal (GDBusProxy* proxy,
                                const gchar* sender_name,
                                const gchar* signal_name,
                                GVariant* parameters)
{
	if (strcmp (signal_name, "NameOwnerChanged") == 0) {
		_dbus_handle_mpris_dbus_impl_name_owner_changed ((MprisDBusImpl*) proxy, parameters);
	} else if (strcmp (signal_name, "NameAcquired") == 0) {
		_dbus_handle_mpris_dbus_impl_name_acquired ((MprisDBusImpl*) proxy, parameters);
	}
}

static void
mpris_dbus_impl_proxy_class_finalize (MprisDBusImplProxyClass* klass)
{
}

void
mpris_dbus_impl_proxy_register_dynamic_type (GTypeModule* module)
{
	mpris_dbus_impl_proxy_register_type (module);
}

static void
mpris_dbus_impl_proxy_init (MprisDBusImplProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_mpris_dbus_impl_dbus_interface_info));
}

static void
_vala_g_async_ready_callback (GObject *source_object,
                              GAsyncResult *res,
                              void *user_data)
{
	g_task_return_pointer (user_data, g_object_ref (res), g_object_unref);
	g_object_unref (user_data);
}

static void
mpris_dbus_impl_proxy_list_names_async (MprisDBusImpl* self,
                                        GAsyncReadyCallback _callback_,
                                        gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.freedesktop.DBus", "ListNames");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static gchar**
mpris_dbus_impl_proxy_list_names_finish (MprisDBusImpl* self,
                                         GAsyncResult* _res_,
                                         gint* result_length1,
                                         GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	GVariant *_reply;
	GVariantIter _reply_iter;
	gchar** _result = NULL;
	gint _result_length1;
	GVariant* _tmp4_;
	gchar** _tmp5_;
	gint _tmp5__length;
	gint _tmp5__size;
	gint _tmp5__length1;
	GVariantIter _tmp6_;
	GVariant* _tmp7_;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return NULL;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return NULL;
	}
	_reply = g_dbus_message_get_body (_reply_message);
	g_variant_iter_init (&_reply_iter, _reply);
	_result_length1 = 0;
	_tmp4_ = g_variant_iter_next_value (&_reply_iter);
	_tmp5_ = g_new (gchar*, 5);
	_tmp5__length = 0;
	_tmp5__size = 4;
	_tmp5__length1 = 0;
	g_variant_iter_init (&_tmp6_, _tmp4_);
	for (; (_tmp7_ = g_variant_iter_next_value (&_tmp6_)) != NULL; _tmp5__length1++) {
		if (_tmp5__size == _tmp5__length) {
			_tmp5__size = 2 * _tmp5__size;
			_tmp5_ = g_renew (gchar*, _tmp5_, _tmp5__size + 1);
		}
		_tmp5_[_tmp5__length++] = g_variant_dup_string (_tmp7_, NULL);
		g_variant_unref (_tmp7_);
	}
	_result_length1 = _tmp5__length1;
	_tmp5_[_tmp5__length] = NULL;
	_result = _tmp5_;
	g_variant_unref (_tmp4_);
	*result_length1 = _result_length1;
	g_object_unref (_reply_message);
	return _result;
}

static void
mpris_dbus_impl_proxy_mpris_dbus_impl_interface_init (MprisDBusImplIface* iface)
{
	iface->list_names = mpris_dbus_impl_proxy_list_names_async;
	iface->list_names_finish = mpris_dbus_impl_proxy_list_names_finish;
}

static void
_dbus_mpris_dbus_impl_list_names (MprisDBusImpl* self,
                                  GVariant* _parameters_,
                                  GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisDbusImplListNamesReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisDbusImplListNamesReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_dbus_impl_list_names (self, (GAsyncReadyCallback) _dbus_mpris_dbus_impl_list_names_ready, _ready_data);
}

static void
_dbus_mpris_dbus_impl_list_names_ready (GObject * source_object,
                                        GAsyncResult * _res_,
                                        gpointer _user_data_)
{
	MprisDbusImplListNamesReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gchar** result;
	gint result_length1 = 0;
	gchar** _tmp8_;
	GVariantBuilder _tmp9_;
	gint _tmp10_;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	result = mpris_dbus_impl_list_names_finish ((MprisDBusImpl*) source_object, _res_, &result_length1, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_tmp8_ = result;
	g_variant_builder_init (&_tmp9_, G_VARIANT_TYPE ("as"));
	for (_tmp10_ = 0; _tmp10_ < result_length1; _tmp10_++) {
		g_variant_builder_add_value (&_tmp9_, g_variant_new_string (*_tmp8_));
		_tmp8_++;
	}
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp9_));
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_free), NULL);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisDbusImplListNamesReadyData, _ready_data);
}

static void
mpris_dbus_impl_dbus_interface_method_call (GDBusConnection* connection,
                                            const gchar* sender,
                                            const gchar* object_path,
                                            const gchar* interface_name,
                                            const gchar* method_name,
                                            GVariant* parameters,
                                            GDBusMethodInvocation* invocation,
                                            gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "ListNames") == 0) {
		_dbus_mpris_dbus_impl_list_names (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
mpris_dbus_impl_dbus_interface_get_property (GDBusConnection* connection,
                                             const gchar* sender,
                                             const gchar* object_path,
                                             const gchar* interface_name,
                                             const gchar* property_name,
                                             GError** error,
                                             gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}

static gboolean
mpris_dbus_impl_dbus_interface_set_property (GDBusConnection* connection,
                                             const gchar* sender,
                                             const gchar* object_path,
                                             const gchar* interface_name,
                                             const gchar* property_name,
                                             GVariant* value,
                                             GError** error,
                                             gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}

static void
_dbus_mpris_dbus_impl_name_owner_changed (GObject* _sender,
                                          const gchar* name,
                                          const gchar* old_owner,
                                          const gchar* new_owner,
                                          gpointer* _data)
{
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (name));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (old_owner));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (new_owner));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.freedesktop.DBus", "NameOwnerChanged", _arguments, NULL);
}

static void
_dbus_mpris_dbus_impl_name_acquired (GObject* _sender,
                                     const gchar* name,
                                     gpointer* _data)
{
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (name));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.freedesktop.DBus", "NameAcquired", _arguments, NULL);
}

guint
mpris_dbus_impl_register_object (gpointer object,
                                 GDBusConnection* connection,
                                 const gchar* path,
                                 GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_mpris_dbus_impl_dbus_interface_info), &_mpris_dbus_impl_dbus_interface_vtable, data, _mpris_dbus_impl_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "name-owner-changed", (GCallback) _dbus_mpris_dbus_impl_name_owner_changed, data);
	g_signal_connect (object, "name-acquired", (GCallback) _dbus_mpris_dbus_impl_name_acquired, data);
	return result;
}

static void
_mpris_dbus_impl_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_signal_handlers_disconnect_by_func (data[0], _dbus_mpris_dbus_impl_name_owner_changed, data);
	g_signal_handlers_disconnect_by_func (data[0], _dbus_mpris_dbus_impl_name_acquired, data);
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

static void
g_cclosure_user_marshal_VOID__STRING_BOXED_BOXED_INT (GClosure * closure,
                                                      GValue * return_value,
                                                      guint n_param_values,
                                                      const GValue * param_values,
                                                      gpointer invocation_hint,
                                                      gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_BOXED_BOXED_INT) (gpointer data1, const char* arg_1, gpointer arg_2, gpointer arg_3, gint arg_4, gpointer data2);
	register GMarshalFunc_VOID__STRING_BOXED_BOXED_INT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
	g_return_if_fail (n_param_values == 5);
	if (G_CCLOSURE_SWAP_DATA (closure)) {
		data1 = closure->data;
		data2 = param_values->data[0].v_pointer;
	} else {
		data1 = param_values->data[0].v_pointer;
		data2 = closure->data;
	}
	callback = (GMarshalFunc_VOID__STRING_BOXED_BOXED_INT) (marshal_data ? marshal_data : cc->callback);
	callback (data1, g_value_get_string (param_values + 1), g_value_get_boxed (param_values + 2), g_value_get_boxed (param_values + 3), g_value_get_int (param_values + 4), data2);
}

static void
mpris_dbus_prop_iface_default_init (MprisDbusPropIfaceIface * iface,
                                    gpointer iface_data)
{
	mpris_dbus_prop_iface_signals[MPRIS_DBUS_PROP_IFACE_PROPERTIES_CHANGED_SIGNAL] = g_signal_new ("properties-changed", TYPE_MPRIS_DBUS_PROP_IFACE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_BOXED_BOXED_INT, G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_HASH_TABLE, G_TYPE_STRV, G_TYPE_INT);
}

/**
 * Vala dbus property notifications are not working. Manually probe property changes.
 */
GType
mpris_dbus_prop_iface_get_type (void)
{
	return mpris_dbus_prop_iface_type_id;
}

GType
mpris_dbus_prop_iface_register_type (GTypeModule * module)
{
	static const GTypeInfo g_define_type_info = { sizeof (MprisDbusPropIfaceIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) mpris_dbus_prop_iface_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	mpris_dbus_prop_iface_type_id = g_type_module_register_type (module, G_TYPE_INTERFACE, "MprisDbusPropIface", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (mpris_dbus_prop_iface_type_id, G_TYPE_OBJECT);
	g_type_set_qdata (mpris_dbus_prop_iface_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) mpris_dbus_prop_iface_proxy_get_type);
	g_type_set_qdata (mpris_dbus_prop_iface_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.DBus.Properties");
	g_type_set_qdata (mpris_dbus_prop_iface_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_mpris_dbus_prop_iface_dbus_interface_info));
	g_type_set_qdata (mpris_dbus_prop_iface_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) mpris_dbus_prop_iface_register_object);
	return mpris_dbus_prop_iface_type_id;
}

G_DEFINE_DYNAMIC_TYPE_EXTENDED (MprisDbusPropIfaceProxy, mpris_dbus_prop_iface_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE_DYNAMIC (TYPE_MPRIS_DBUS_PROP_IFACE, mpris_dbus_prop_iface_proxy_mpris_dbus_prop_iface_interface_init) )
static void
mpris_dbus_prop_iface_proxy_class_init (MprisDbusPropIfaceProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = mpris_dbus_prop_iface_proxy_g_signal;
}

static void
_dbus_handle_mpris_dbus_prop_iface_properties_changed (MprisDbusPropIface* self,
                                                       GVariant* parameters)
{
	GVariantIter _arguments_iter;
	gchar* iface = NULL;
	GVariant* _tmp11_;
	GHashTable* changed = NULL;
	GVariant* _tmp12_;
	GHashTable* _tmp13_;
	GVariantIter _tmp14_;
	GVariant* _tmp15_;
	GVariant* _tmp16_;
	gchar** invalid = NULL;
	gint invalid_length1;
	GVariant* _tmp17_;
	gchar** _tmp18_;
	gint _tmp18__length;
	gint _tmp18__size;
	gint _tmp18__length1;
	GVariantIter _tmp19_;
	GVariant* _tmp20_;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp11_ = g_variant_iter_next_value (&_arguments_iter);
	iface = g_variant_dup_string (_tmp11_, NULL);
	g_variant_unref (_tmp11_);
	_tmp12_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp13_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_variant_unref);
	g_variant_iter_init (&_tmp14_, _tmp12_);
	while (g_variant_iter_loop (&_tmp14_, "{?*}", &_tmp15_, &_tmp16_)) {
		g_hash_table_insert (_tmp13_, g_variant_dup_string (_tmp15_, NULL), g_variant_get_variant (_tmp16_));
	}
	changed = _tmp13_;
	g_variant_unref (_tmp12_);
	invalid_length1 = 0;
	_tmp17_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp18_ = g_new (gchar*, 5);
	_tmp18__length = 0;
	_tmp18__size = 4;
	_tmp18__length1 = 0;
	g_variant_iter_init (&_tmp19_, _tmp17_);
	for (; (_tmp20_ = g_variant_iter_next_value (&_tmp19_)) != NULL; _tmp18__length1++) {
		if (_tmp18__size == _tmp18__length) {
			_tmp18__size = 2 * _tmp18__size;
			_tmp18_ = g_renew (gchar*, _tmp18_, _tmp18__size + 1);
		}
		_tmp18_[_tmp18__length++] = g_variant_dup_string (_tmp20_, NULL);
		g_variant_unref (_tmp20_);
	}
	invalid_length1 = _tmp18__length1;
	_tmp18_[_tmp18__length] = NULL;
	invalid = _tmp18_;
	g_variant_unref (_tmp17_);
	g_signal_emit_by_name (self, "properties-changed", iface, changed, invalid, invalid_length1);
	_g_free0 (iface);
	_g_hash_table_unref0 (changed);
	invalid = (_vala_array_free (invalid, invalid_length1, (GDestroyNotify) g_free), NULL);
}

static void
mpris_dbus_prop_iface_proxy_g_signal (GDBusProxy* proxy,
                                      const gchar* sender_name,
                                      const gchar* signal_name,
                                      GVariant* parameters)
{
	if (strcmp (signal_name, "PropertiesChanged") == 0) {
		_dbus_handle_mpris_dbus_prop_iface_properties_changed ((MprisDbusPropIface*) proxy, parameters);
	}
}

static void
mpris_dbus_prop_iface_proxy_class_finalize (MprisDbusPropIfaceProxyClass* klass)
{
}

void
mpris_dbus_prop_iface_proxy_register_dynamic_type (GTypeModule* module)
{
	mpris_dbus_prop_iface_proxy_register_type (module);
}

static void
mpris_dbus_prop_iface_proxy_init (MprisDbusPropIfaceProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_mpris_dbus_prop_iface_dbus_interface_info));
}

static void
mpris_dbus_prop_iface_proxy_mpris_dbus_prop_iface_interface_init (MprisDbusPropIfaceIface* iface)
{
}

static void
mpris_dbus_prop_iface_dbus_interface_method_call (GDBusConnection* connection,
                                                  const gchar* sender,
                                                  const gchar* object_path,
                                                  const gchar* interface_name,
                                                  const gchar* method_name,
                                                  GVariant* parameters,
                                                  GDBusMethodInvocation* invocation,
                                                  gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	g_object_unref (invocation);
}

static GVariant*
mpris_dbus_prop_iface_dbus_interface_get_property (GDBusConnection* connection,
                                                   const gchar* sender,
                                                   const gchar* object_path,
                                                   const gchar* interface_name,
                                                   const gchar* property_name,
                                                   GError** error,
                                                   gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return NULL;
}

static gboolean
mpris_dbus_prop_iface_dbus_interface_set_property (GDBusConnection* connection,
                                                   const gchar* sender,
                                                   const gchar* object_path,
                                                   const gchar* interface_name,
                                                   const gchar* property_name,
                                                   GVariant* value,
                                                   GError** error,
                                                   gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	return FALSE;
}

static void
_dbus_mpris_dbus_prop_iface_properties_changed (GObject* _sender,
                                                const gchar* iface,
                                                GHashTable* changed,
                                                gchar** invalid,
                                                gint invalid_length1,
                                                gpointer* _data)
{
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GVariantBuilder _tmp21_;
	GHashTableIter _tmp22_;
	gpointer _tmp23_;
	gpointer _tmp24_;
	gchar** _tmp25_;
	GVariantBuilder _tmp26_;
	gint _tmp27_;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (iface));
	g_hash_table_iter_init (&_tmp22_, changed);
	g_variant_builder_init (&_tmp21_, G_VARIANT_TYPE ("a{sv}"));
	while (g_hash_table_iter_next (&_tmp22_, &_tmp23_, &_tmp24_)) {
		gchar* _key;
		GVariant* _value;
		_key = (gchar*) _tmp23_;
		_value = (GVariant*) _tmp24_;
		g_variant_builder_add (&_tmp21_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp21_));
	_tmp25_ = invalid;
	g_variant_builder_init (&_tmp26_, G_VARIANT_TYPE ("as"));
	for (_tmp27_ = 0; _tmp27_ < invalid_length1; _tmp27_++) {
		g_variant_builder_add_value (&_tmp26_, g_variant_new_string (*_tmp25_));
		_tmp25_++;
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp26_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.freedesktop.DBus.Properties", "PropertiesChanged", _arguments, NULL);
}

guint
mpris_dbus_prop_iface_register_object (gpointer object,
                                       GDBusConnection* connection,
                                       const gchar* path,
                                       GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_mpris_dbus_prop_iface_dbus_interface_info), &_mpris_dbus_prop_iface_dbus_interface_vtable, data, _mpris_dbus_prop_iface_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "properties-changed", (GCallback) _dbus_mpris_dbus_prop_iface_properties_changed, data);
	return result;
}

static void
_mpris_dbus_prop_iface_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_signal_handlers_disconnect_by_func (data[0], _dbus_mpris_dbus_prop_iface_properties_changed, data);
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

void
mpris_iface_raise (MprisIface* self,
                   GAsyncReadyCallback _callback_,
                   gpointer _user_data_)
{
	MprisIfaceIface* _iface_;
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->raise) {
		_iface_->raise (self, _callback_, _user_data_);
	}
}

void
mpris_iface_raise_finish (MprisIface* self,
                          GAsyncResult* _res_,
                          GError** error)
{
	MprisIfaceIface* _iface_;
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->raise_finish) {
		_iface_->raise_finish (self, _res_, error);
	}
}

void
mpris_iface_quit (MprisIface* self,
                  GAsyncReadyCallback _callback_,
                  gpointer _user_data_)
{
	MprisIfaceIface* _iface_;
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->quit) {
		_iface_->quit (self, _callback_, _user_data_);
	}
}

void
mpris_iface_quit_finish (MprisIface* self,
                         GAsyncResult* _res_,
                         GError** error)
{
	MprisIfaceIface* _iface_;
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->quit_finish) {
		_iface_->quit_finish (self, _res_, error);
	}
}

gboolean
mpris_iface_get_can_quit (MprisIface* self)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_quit) {
		return _iface_->get_can_quit (self);
	}
	return FALSE;
}

void
mpris_iface_set_can_quit (MprisIface* self,
                          gboolean value)
{
	MprisIfaceIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->set_can_quit) {
		_iface_->set_can_quit (self, value);
	}
}

gboolean
mpris_iface_get_fullscreen (MprisIface* self)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_fullscreen) {
		return _iface_->get_fullscreen (self);
	}
	return FALSE;
}

gboolean
mpris_iface_get_can_set_fullscreen (MprisIface* self)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_set_fullscreen) {
		return _iface_->get_can_set_fullscreen (self);
	}
	return FALSE;
}

gboolean
mpris_iface_get_can_raise (MprisIface* self)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_raise) {
		return _iface_->get_can_raise (self);
	}
	return FALSE;
}

gboolean
mpris_iface_get_has_track_list (MprisIface* self)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_has_track_list) {
		return _iface_->get_has_track_list (self);
	}
	return FALSE;
}

gchar*
mpris_iface_get_identity (MprisIface* self)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_identity) {
		return _iface_->get_identity (self);
	}
	return NULL;
}

gchar*
mpris_iface_get_desktop_entry (MprisIface* self)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_desktop_entry) {
		return _iface_->get_desktop_entry (self);
	}
	return NULL;
}

gchar**
mpris_iface_get_supported_uri_schemes (MprisIface* self,
                                       gint* result_length1)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_supported_uri_schemes) {
		return _iface_->get_supported_uri_schemes (self, result_length1);
	}
	return NULL;
}

gchar**
mpris_iface_get_supported_mime_types (MprisIface* self,
                                      gint* result_length1)
{
	MprisIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = MPRIS_IFACE_GET_INTERFACE (self);
	if (_iface_->get_supported_mime_types) {
		return _iface_->get_supported_mime_types (self, result_length1);
	}
	return NULL;
}

static void
mpris_iface_default_init (MprisIfaceIface * iface,
                          gpointer iface_data)
{
}

/**
 * Represents the base org.mpris.MediaPlayer2 spec
 */
GType
mpris_iface_get_type (void)
{
	return mpris_iface_type_id;
}

GType
mpris_iface_register_type (GTypeModule * module)
{
	static const GTypeInfo g_define_type_info = { sizeof (MprisIfaceIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) mpris_iface_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	mpris_iface_type_id = g_type_module_register_type (module, G_TYPE_INTERFACE, "MprisIface", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (mpris_iface_type_id, G_TYPE_OBJECT);
	g_type_set_qdata (mpris_iface_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) mpris_iface_proxy_get_type);
	g_type_set_qdata (mpris_iface_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.mpris.MediaPlayer2");
	g_type_set_qdata (mpris_iface_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_mpris_iface_dbus_interface_info));
	g_type_set_qdata (mpris_iface_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) mpris_iface_register_object);
	return mpris_iface_type_id;
}

G_DEFINE_DYNAMIC_TYPE_EXTENDED (MprisIfaceProxy, mpris_iface_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE_DYNAMIC (TYPE_MPRIS_IFACE, mpris_iface_proxy_mpris_iface_interface_init) )
static void
mpris_iface_proxy_class_init (MprisIfaceProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = mpris_iface_proxy_g_signal;
}

static void
mpris_iface_proxy_g_signal (GDBusProxy* proxy,
                            const gchar* sender_name,
                            const gchar* signal_name,
                            GVariant* parameters)
{
}

static void
mpris_iface_proxy_class_finalize (MprisIfaceProxyClass* klass)
{
}

void
mpris_iface_proxy_register_dynamic_type (GTypeModule* module)
{
	mpris_iface_proxy_register_type (module);
}

static void
mpris_iface_proxy_init (MprisIfaceProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_mpris_iface_dbus_interface_info));
}

static void
mpris_iface_proxy_raise_async (MprisIface* self,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2", "Raise");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_iface_proxy_raise_finish (MprisIface* self,
                                GAsyncResult* _res_,
                                GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_iface_proxy_quit_async (MprisIface* self,
                              GAsyncReadyCallback _callback_,
                              gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2", "Quit");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_iface_proxy_quit_finish (MprisIface* self,
                               GAsyncResult* _res_,
                               GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static gboolean
mpris_iface_dbus_proxy_get_can_quit (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanQuit");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanQuit"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp28_ = FALSE;
			return _tmp28_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_iface_dbus_proxy_set_can_quit (MprisIface* self,
                                     gboolean value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanQuit"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static gboolean
mpris_iface_dbus_proxy_get_fullscreen (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Fullscreen");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Fullscreen"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp29_ = FALSE;
			return _tmp29_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_iface_dbus_proxy_get_can_set_fullscreen (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanSetFullscreen");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanSetFullscreen"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp30_ = FALSE;
			return _tmp30_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_iface_dbus_proxy_get_can_raise (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanRaise");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanRaise"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp31_ = FALSE;
			return _tmp31_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_iface_dbus_proxy_get_has_track_list (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "HasTrackList");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("HasTrackList"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp32_ = FALSE;
			return _tmp32_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
mpris_iface_dbus_proxy_get_identity (MprisIface* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Identity");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Identity"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
mpris_iface_dbus_proxy_get_desktop_entry (MprisIface* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "DesktopEntry");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("DesktopEntry"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar**
mpris_iface_dbus_proxy_get_supported_uri_schemes (MprisIface* self,
                                                  gint* result_length1)
{
	GVariant *_inner_reply;
	gchar** _result;
	gint _result_length1;
	gchar** _tmp33_;
	gint _tmp33__length;
	gint _tmp33__size;
	gint _tmp33__length1;
	GVariantIter _tmp34_;
	GVariant* _tmp35_;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "SupportedUriSchemes");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("SupportedUriSchemes"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result_length1 = 0;
	_tmp33_ = g_new (gchar*, 5);
	_tmp33__length = 0;
	_tmp33__size = 4;
	_tmp33__length1 = 0;
	g_variant_iter_init (&_tmp34_, _inner_reply);
	for (; (_tmp35_ = g_variant_iter_next_value (&_tmp34_)) != NULL; _tmp33__length1++) {
		if (_tmp33__size == _tmp33__length) {
			_tmp33__size = 2 * _tmp33__size;
			_tmp33_ = g_renew (gchar*, _tmp33_, _tmp33__size + 1);
		}
		_tmp33_[_tmp33__length++] = g_variant_dup_string (_tmp35_, NULL);
		g_variant_unref (_tmp35_);
	}
	_result_length1 = _tmp33__length1;
	_tmp33_[_tmp33__length] = NULL;
	_result = _tmp33_;
	*result_length1 = _result_length1;
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar**
mpris_iface_dbus_proxy_get_supported_mime_types (MprisIface* self,
                                                 gint* result_length1)
{
	GVariant *_inner_reply;
	gchar** _result;
	gint _result_length1;
	gchar** _tmp36_;
	gint _tmp36__length;
	gint _tmp36__size;
	gint _tmp36__length1;
	GVariantIter _tmp37_;
	GVariant* _tmp38_;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "SupportedMimeTypes");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("SupportedMimeTypes"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result_length1 = 0;
	_tmp36_ = g_new (gchar*, 5);
	_tmp36__length = 0;
	_tmp36__size = 4;
	_tmp36__length1 = 0;
	g_variant_iter_init (&_tmp37_, _inner_reply);
	for (; (_tmp38_ = g_variant_iter_next_value (&_tmp37_)) != NULL; _tmp36__length1++) {
		if (_tmp36__size == _tmp36__length) {
			_tmp36__size = 2 * _tmp36__size;
			_tmp36_ = g_renew (gchar*, _tmp36_, _tmp36__size + 1);
		}
		_tmp36_[_tmp36__length++] = g_variant_dup_string (_tmp38_, NULL);
		g_variant_unref (_tmp38_);
	}
	_result_length1 = _tmp36__length1;
	_tmp36_[_tmp36__length] = NULL;
	_result = _tmp36_;
	*result_length1 = _result_length1;
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_iface_proxy_mpris_iface_interface_init (MprisIfaceIface* iface)
{
	iface->raise = mpris_iface_proxy_raise_async;
	iface->raise_finish = mpris_iface_proxy_raise_finish;
	iface->quit = mpris_iface_proxy_quit_async;
	iface->quit_finish = mpris_iface_proxy_quit_finish;
	iface->get_can_quit = mpris_iface_dbus_proxy_get_can_quit;
	iface->set_can_quit = mpris_iface_dbus_proxy_set_can_quit;
	iface->get_fullscreen = mpris_iface_dbus_proxy_get_fullscreen;
	iface->get_can_set_fullscreen = mpris_iface_dbus_proxy_get_can_set_fullscreen;
	iface->get_can_raise = mpris_iface_dbus_proxy_get_can_raise;
	iface->get_has_track_list = mpris_iface_dbus_proxy_get_has_track_list;
	iface->get_identity = mpris_iface_dbus_proxy_get_identity;
	iface->get_desktop_entry = mpris_iface_dbus_proxy_get_desktop_entry;
	iface->get_supported_uri_schemes = mpris_iface_dbus_proxy_get_supported_uri_schemes;
	iface->get_supported_mime_types = mpris_iface_dbus_proxy_get_supported_mime_types;
}

static void
_dbus_mpris_iface_raise (MprisIface* self,
                         GVariant* _parameters_,
                         GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisIfaceRaiseReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisIfaceRaiseReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_iface_raise (self, (GAsyncReadyCallback) _dbus_mpris_iface_raise_ready, _ready_data);
}

static void
_dbus_mpris_iface_raise_ready (GObject * source_object,
                               GAsyncResult * _res_,
                               gpointer _user_data_)
{
	MprisIfaceRaiseReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_iface_raise_finish ((MprisIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisIfaceRaiseReadyData, _ready_data);
}

static void
_dbus_mpris_iface_quit (MprisIface* self,
                        GVariant* _parameters_,
                        GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisIfaceQuitReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisIfaceQuitReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_iface_quit (self, (GAsyncReadyCallback) _dbus_mpris_iface_quit_ready, _ready_data);
}

static void
_dbus_mpris_iface_quit_ready (GObject * source_object,
                              GAsyncResult * _res_,
                              gpointer _user_data_)
{
	MprisIfaceQuitReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_iface_quit_finish ((MprisIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisIfaceQuitReadyData, _ready_data);
}

static void
mpris_iface_dbus_interface_method_call (GDBusConnection* connection,
                                        const gchar* sender,
                                        const gchar* object_path,
                                        const gchar* interface_name,
                                        const gchar* method_name,
                                        GVariant* parameters,
                                        GDBusMethodInvocation* invocation,
                                        gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "Raise") == 0) {
		_dbus_mpris_iface_raise (object, parameters, invocation);
	} else if (strcmp (method_name, "Quit") == 0) {
		_dbus_mpris_iface_quit (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
_dbus_mpris_iface_get_can_quit (MprisIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_iface_get_can_quit (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_iface_get_fullscreen (MprisIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_iface_get_fullscreen (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_iface_get_can_set_fullscreen (MprisIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_iface_get_can_set_fullscreen (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_iface_get_can_raise (MprisIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_iface_get_can_raise (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_iface_get_has_track_list (MprisIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_iface_get_has_track_list (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_iface_get_identity (MprisIface* self)
{
	gchar* result;
	GVariant* _reply;
	result = mpris_iface_get_identity (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_mpris_iface_get_desktop_entry (MprisIface* self)
{
	gchar* result;
	GVariant* _reply;
	result = mpris_iface_get_desktop_entry (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_mpris_iface_get_supported_uri_schemes (MprisIface* self)
{
	gchar** result;
	gint result_length1 = 0;
	GVariant* _reply;
	gchar** _tmp39_;
	GVariantBuilder _tmp40_;
	gint _tmp41_;
	result = mpris_iface_get_supported_uri_schemes (self, &result_length1);
	_tmp39_ = result;
	g_variant_builder_init (&_tmp40_, G_VARIANT_TYPE ("as"));
	for (_tmp41_ = 0; _tmp41_ < result_length1; _tmp41_++) {
		g_variant_builder_add_value (&_tmp40_, g_variant_new_string (*_tmp39_));
		_tmp39_++;
	}
	_reply = g_variant_builder_end (&_tmp40_);
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_free), NULL);
	return _reply;
}

static GVariant*
_dbus_mpris_iface_get_supported_mime_types (MprisIface* self)
{
	gchar** result;
	gint result_length1 = 0;
	GVariant* _reply;
	gchar** _tmp42_;
	GVariantBuilder _tmp43_;
	gint _tmp44_;
	result = mpris_iface_get_supported_mime_types (self, &result_length1);
	_tmp42_ = result;
	g_variant_builder_init (&_tmp43_, G_VARIANT_TYPE ("as"));
	for (_tmp44_ = 0; _tmp44_ < result_length1; _tmp44_++) {
		g_variant_builder_add_value (&_tmp43_, g_variant_new_string (*_tmp42_));
		_tmp42_++;
	}
	_reply = g_variant_builder_end (&_tmp43_);
	result = (_vala_array_free (result, result_length1, (GDestroyNotify) g_free), NULL);
	return _reply;
}

static GVariant*
mpris_iface_dbus_interface_get_property (GDBusConnection* connection,
                                         const gchar* sender,
                                         const gchar* object_path,
                                         const gchar* interface_name,
                                         const gchar* property_name,
                                         GError** error,
                                         gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "CanQuit") == 0) {
		return _dbus_mpris_iface_get_can_quit (object);
	} else if (strcmp (property_name, "Fullscreen") == 0) {
		return _dbus_mpris_iface_get_fullscreen (object);
	} else if (strcmp (property_name, "CanSetFullscreen") == 0) {
		return _dbus_mpris_iface_get_can_set_fullscreen (object);
	} else if (strcmp (property_name, "CanRaise") == 0) {
		return _dbus_mpris_iface_get_can_raise (object);
	} else if (strcmp (property_name, "HasTrackList") == 0) {
		return _dbus_mpris_iface_get_has_track_list (object);
	} else if (strcmp (property_name, "Identity") == 0) {
		return _dbus_mpris_iface_get_identity (object);
	} else if (strcmp (property_name, "DesktopEntry") == 0) {
		return _dbus_mpris_iface_get_desktop_entry (object);
	} else if (strcmp (property_name, "SupportedUriSchemes") == 0) {
		return _dbus_mpris_iface_get_supported_uri_schemes (object);
	} else if (strcmp (property_name, "SupportedMimeTypes") == 0) {
		return _dbus_mpris_iface_get_supported_mime_types (object);
	}
	return NULL;
}

static void
_dbus_mpris_iface_set_can_quit (MprisIface* self,
                                GVariant* _value)
{
	gboolean value = FALSE;
	value = g_variant_get_boolean (_value);
	mpris_iface_set_can_quit (self, value);
}

static gboolean
mpris_iface_dbus_interface_set_property (GDBusConnection* connection,
                                         const gchar* sender,
                                         const gchar* object_path,
                                         const gchar* interface_name,
                                         const gchar* property_name,
                                         GVariant* value,
                                         GError** error,
                                         gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "CanQuit") == 0) {
		_dbus_mpris_iface_set_can_quit (object, value);
		return TRUE;
	}
	return FALSE;
}

guint
mpris_iface_register_object (gpointer object,
                             GDBusConnection* connection,
                             const gchar* path,
                             GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_mpris_iface_dbus_interface_info), &_mpris_iface_dbus_interface_vtable, data, _mpris_iface_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}

static void
_mpris_iface_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

void
mpris_player_iface_next (MprisPlayerIface* self,
                         GAsyncReadyCallback _callback_,
                         gpointer _user_data_)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->next) {
		_iface_->next (self, _callback_, _user_data_);
	}
}

void
mpris_player_iface_next_finish (MprisPlayerIface* self,
                                GAsyncResult* _res_,
                                GError** error)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->next_finish) {
		_iface_->next_finish (self, _res_, error);
	}
}

void
mpris_player_iface_previous (MprisPlayerIface* self,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->previous) {
		_iface_->previous (self, _callback_, _user_data_);
	}
}

void
mpris_player_iface_previous_finish (MprisPlayerIface* self,
                                    GAsyncResult* _res_,
                                    GError** error)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->previous_finish) {
		_iface_->previous_finish (self, _res_, error);
	}
}

void
mpris_player_iface_pause (MprisPlayerIface* self,
                          GAsyncReadyCallback _callback_,
                          gpointer _user_data_)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->pause) {
		_iface_->pause (self, _callback_, _user_data_);
	}
}

void
mpris_player_iface_pause_finish (MprisPlayerIface* self,
                                 GAsyncResult* _res_,
                                 GError** error)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->pause_finish) {
		_iface_->pause_finish (self, _res_, error);
	}
}

void
mpris_player_iface_play_pause (MprisPlayerIface* self,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->play_pause) {
		_iface_->play_pause (self, _callback_, _user_data_);
	}
}

void
mpris_player_iface_play_pause_finish (MprisPlayerIface* self,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->play_pause_finish) {
		_iface_->play_pause_finish (self, _res_, error);
	}
}

void
mpris_player_iface_stop (MprisPlayerIface* self,
                         GAsyncReadyCallback _callback_,
                         gpointer _user_data_)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->stop) {
		_iface_->stop (self, _callback_, _user_data_);
	}
}

void
mpris_player_iface_stop_finish (MprisPlayerIface* self,
                                GAsyncResult* _res_,
                                GError** error)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->stop_finish) {
		_iface_->stop_finish (self, _res_, error);
	}
}

void
mpris_player_iface_play (MprisPlayerIface* self,
                         GAsyncReadyCallback _callback_,
                         gpointer _user_data_)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->play) {
		_iface_->play (self, _callback_, _user_data_);
	}
}

void
mpris_player_iface_play_finish (MprisPlayerIface* self,
                                GAsyncResult* _res_,
                                GError** error)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->play_finish) {
		_iface_->play_finish (self, _res_, error);
	}
}

void
mpris_player_iface_seek (MprisPlayerIface* self,
                         gint64 offset,
                         GAsyncReadyCallback _callback_,
                         gpointer _user_data_)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->seek) {
		_iface_->seek (self, offset, _callback_, _user_data_);
	}
}

void
mpris_player_iface_seek_finish (MprisPlayerIface* self,
                                GAsyncResult* _res_,
                                GError** error)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->seek_finish) {
		_iface_->seek_finish (self, _res_, error);
	}
}

void
mpris_player_iface_open_uri (MprisPlayerIface* self,
                             const gchar* uri,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->open_uri) {
		_iface_->open_uri (self, uri, _callback_, _user_data_);
	}
}

void
mpris_player_iface_open_uri_finish (MprisPlayerIface* self,
                                    GAsyncResult* _res_,
                                    GError** error)
{
	MprisPlayerIfaceIface* _iface_;
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->open_uri_finish) {
		_iface_->open_uri_finish (self, _res_, error);
	}
}

gchar*
mpris_player_iface_get_playback_status (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_playback_status) {
		return _iface_->get_playback_status (self);
	}
	return NULL;
}

gchar*
mpris_player_iface_get_loop_status (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_loop_status) {
		return _iface_->get_loop_status (self);
	}
	return NULL;
}

void
mpris_player_iface_set_loop_status (MprisPlayerIface* self,
                                    const gchar* value)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->set_loop_status) {
		_iface_->set_loop_status (self, value);
	}
}

gdouble
mpris_player_iface_get_rate (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, 0.0);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_rate) {
		return _iface_->get_rate (self);
	}
	return -1.0;
}

void
mpris_player_iface_set_rate (MprisPlayerIface* self,
                             gdouble value)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->set_rate) {
		_iface_->set_rate (self, value);
	}
}

gboolean
mpris_player_iface_get_shuffle (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_shuffle) {
		return _iface_->get_shuffle (self);
	}
	return FALSE;
}

void
mpris_player_iface_set_shuffle (MprisPlayerIface* self,
                                gboolean value)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->set_shuffle) {
		_iface_->set_shuffle (self, value);
	}
}

GHashTable*
mpris_player_iface_get_metadata (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_metadata) {
		return _iface_->get_metadata (self);
	}
	return NULL;
}

gdouble
mpris_player_iface_get_volume (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, 0.0);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_volume) {
		return _iface_->get_volume (self);
	}
	return -1.0;
}

void
mpris_player_iface_set_volume (MprisPlayerIface* self,
                               gdouble value)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->set_volume) {
		_iface_->set_volume (self, value);
	}
}

gint64
mpris_player_iface_get_position (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, 0LL);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_position) {
		return _iface_->get_position (self);
	}
	return -1LL;
}

gdouble
mpris_player_iface_get_minimum_rate (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, 0.0);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_minimum_rate) {
		return _iface_->get_minimum_rate (self);
	}
	return -1.0;
}

gdouble
mpris_player_iface_get_maximum_rate (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, 0.0);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_maximum_rate) {
		return _iface_->get_maximum_rate (self);
	}
	return -1.0;
}

gboolean
mpris_player_iface_get_can_go_next (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_go_next) {
		return _iface_->get_can_go_next (self);
	}
	return FALSE;
}

gboolean
mpris_player_iface_get_can_go_previous (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_go_previous) {
		return _iface_->get_can_go_previous (self);
	}
	return FALSE;
}

gboolean
mpris_player_iface_get_can_play (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_play) {
		return _iface_->get_can_play (self);
	}
	return FALSE;
}

gboolean
mpris_player_iface_get_can_pause (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_pause) {
		return _iface_->get_can_pause (self);
	}
	return FALSE;
}

gboolean
mpris_player_iface_get_can_seek (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_seek) {
		return _iface_->get_can_seek (self);
	}
	return FALSE;
}

gboolean
mpris_player_iface_get_can_control (MprisPlayerIface* self)
{
	MprisPlayerIfaceIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = MPRIS_PLAYER_IFACE_GET_INTERFACE (self);
	if (_iface_->get_can_control) {
		return _iface_->get_can_control (self);
	}
	return FALSE;
}

static void
mpris_player_iface_default_init (MprisPlayerIfaceIface * iface,
                                 gpointer iface_data)
{
}

/**
 * Interface for the org.mpris.MediaPlayer2.Player spec
 * This is the one that actually does cool stuff!
 *
 * @note We cheat and inherit from MprisIface to save faffing around with two
 * iface initialisations over one
 */
GType
mpris_player_iface_get_type (void)
{
	return mpris_player_iface_type_id;
}

GType
mpris_player_iface_register_type (GTypeModule * module)
{
	static const GTypeInfo g_define_type_info = { sizeof (MprisPlayerIfaceIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) mpris_player_iface_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	mpris_player_iface_type_id = g_type_module_register_type (module, G_TYPE_INTERFACE, "MprisPlayerIface", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (mpris_player_iface_type_id, TYPE_MPRIS_IFACE);
	g_type_set_qdata (mpris_player_iface_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) mpris_player_iface_proxy_get_type);
	g_type_set_qdata (mpris_player_iface_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.mpris.MediaPlayer2.Player");
	g_type_set_qdata (mpris_player_iface_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_mpris_player_iface_dbus_interface_info));
	g_type_set_qdata (mpris_player_iface_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) mpris_player_iface_register_object);
	return mpris_player_iface_type_id;
}

G_DEFINE_DYNAMIC_TYPE_EXTENDED (MprisPlayerIfaceProxy, mpris_player_iface_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE_DYNAMIC (TYPE_MPRIS_IFACE, mpris_player_iface_proxy_mpris_iface_interface_init) G_IMPLEMENT_INTERFACE_DYNAMIC (TYPE_MPRIS_PLAYER_IFACE, mpris_player_iface_proxy_mpris_player_iface_interface_init) )
static void
mpris_player_iface_proxy_class_init (MprisPlayerIfaceProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = mpris_player_iface_proxy_g_signal;
}

static void
mpris_player_iface_proxy_g_signal (GDBusProxy* proxy,
                                   const gchar* sender_name,
                                   const gchar* signal_name,
                                   GVariant* parameters)
{
}

static void
mpris_player_iface_proxy_class_finalize (MprisPlayerIfaceProxyClass* klass)
{
}

void
mpris_player_iface_proxy_register_dynamic_type (GTypeModule* module)
{
	mpris_player_iface_proxy_register_type (module);
}

static void
mpris_player_iface_proxy_init (MprisPlayerIfaceProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_mpris_player_iface_dbus_interface_info));
}

static void
mpris_player_iface_proxy_raise_async (MprisIface* self,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2", "Raise");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_raise_finish (MprisIface* self,
                                       GAsyncResult* _res_,
                                       GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_player_iface_proxy_quit_async (MprisIface* self,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2", "Quit");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_quit_finish (MprisIface* self,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_quit (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanQuit");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanQuit"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp45_ = FALSE;
			return _tmp45_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_player_iface_dbus_proxy_set_can_quit (MprisIface* self,
                                            gboolean value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanQuit"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static gboolean
mpris_player_iface_dbus_proxy_get_fullscreen (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Fullscreen");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Fullscreen"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp46_ = FALSE;
			return _tmp46_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_set_fullscreen (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanSetFullscreen");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanSetFullscreen"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp47_ = FALSE;
			return _tmp47_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_raise (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanRaise");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanRaise"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp48_ = FALSE;
			return _tmp48_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_has_track_list (MprisIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "HasTrackList");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("HasTrackList"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp49_ = FALSE;
			return _tmp49_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
mpris_player_iface_dbus_proxy_get_identity (MprisIface* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Identity");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Identity"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
mpris_player_iface_dbus_proxy_get_desktop_entry (MprisIface* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "DesktopEntry");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("DesktopEntry"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar**
mpris_player_iface_dbus_proxy_get_supported_uri_schemes (MprisIface* self,
                                                         gint* result_length1)
{
	GVariant *_inner_reply;
	gchar** _result;
	gint _result_length1;
	gchar** _tmp50_;
	gint _tmp50__length;
	gint _tmp50__size;
	gint _tmp50__length1;
	GVariantIter _tmp51_;
	GVariant* _tmp52_;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "SupportedUriSchemes");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("SupportedUriSchemes"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result_length1 = 0;
	_tmp50_ = g_new (gchar*, 5);
	_tmp50__length = 0;
	_tmp50__size = 4;
	_tmp50__length1 = 0;
	g_variant_iter_init (&_tmp51_, _inner_reply);
	for (; (_tmp52_ = g_variant_iter_next_value (&_tmp51_)) != NULL; _tmp50__length1++) {
		if (_tmp50__size == _tmp50__length) {
			_tmp50__size = 2 * _tmp50__size;
			_tmp50_ = g_renew (gchar*, _tmp50_, _tmp50__size + 1);
		}
		_tmp50_[_tmp50__length++] = g_variant_dup_string (_tmp52_, NULL);
		g_variant_unref (_tmp52_);
	}
	_result_length1 = _tmp50__length1;
	_tmp50_[_tmp50__length] = NULL;
	_result = _tmp50_;
	*result_length1 = _result_length1;
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar**
mpris_player_iface_dbus_proxy_get_supported_mime_types (MprisIface* self,
                                                        gint* result_length1)
{
	GVariant *_inner_reply;
	gchar** _result;
	gint _result_length1;
	gchar** _tmp53_;
	gint _tmp53__length;
	gint _tmp53__size;
	gint _tmp53__length1;
	GVariantIter _tmp54_;
	GVariant* _tmp55_;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "SupportedMimeTypes");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("SupportedMimeTypes"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result_length1 = 0;
	_tmp53_ = g_new (gchar*, 5);
	_tmp53__length = 0;
	_tmp53__size = 4;
	_tmp53__length1 = 0;
	g_variant_iter_init (&_tmp54_, _inner_reply);
	for (; (_tmp55_ = g_variant_iter_next_value (&_tmp54_)) != NULL; _tmp53__length1++) {
		if (_tmp53__size == _tmp53__length) {
			_tmp53__size = 2 * _tmp53__size;
			_tmp53_ = g_renew (gchar*, _tmp53_, _tmp53__size + 1);
		}
		_tmp53_[_tmp53__length++] = g_variant_dup_string (_tmp55_, NULL);
		g_variant_unref (_tmp55_);
	}
	_result_length1 = _tmp53__length1;
	_tmp53_[_tmp53__length] = NULL;
	_result = _tmp53_;
	*result_length1 = _result_length1;
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_player_iface_proxy_mpris_iface_interface_init (MprisIfaceIface* iface)
{
	iface->raise = mpris_player_iface_proxy_raise_async;
	iface->raise_finish = mpris_player_iface_proxy_raise_finish;
	iface->quit = mpris_player_iface_proxy_quit_async;
	iface->quit_finish = mpris_player_iface_proxy_quit_finish;
	iface->get_can_quit = mpris_player_iface_dbus_proxy_get_can_quit;
	iface->set_can_quit = mpris_player_iface_dbus_proxy_set_can_quit;
	iface->get_fullscreen = mpris_player_iface_dbus_proxy_get_fullscreen;
	iface->get_can_set_fullscreen = mpris_player_iface_dbus_proxy_get_can_set_fullscreen;
	iface->get_can_raise = mpris_player_iface_dbus_proxy_get_can_raise;
	iface->get_has_track_list = mpris_player_iface_dbus_proxy_get_has_track_list;
	iface->get_identity = mpris_player_iface_dbus_proxy_get_identity;
	iface->get_desktop_entry = mpris_player_iface_dbus_proxy_get_desktop_entry;
	iface->get_supported_uri_schemes = mpris_player_iface_dbus_proxy_get_supported_uri_schemes;
	iface->get_supported_mime_types = mpris_player_iface_dbus_proxy_get_supported_mime_types;
}

static void
mpris_player_iface_proxy_next_async (MprisPlayerIface* self,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2.Player", "Next");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_next_finish (MprisPlayerIface* self,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_player_iface_proxy_previous_async (MprisPlayerIface* self,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2.Player", "Previous");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_previous_finish (MprisPlayerIface* self,
                                          GAsyncResult* _res_,
                                          GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_player_iface_proxy_pause_async (MprisPlayerIface* self,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2.Player", "Pause");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_pause_finish (MprisPlayerIface* self,
                                       GAsyncResult* _res_,
                                       GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_player_iface_proxy_play_pause_async (MprisPlayerIface* self,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2.Player", "PlayPause");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_play_pause_finish (MprisPlayerIface* self,
                                            GAsyncResult* _res_,
                                            GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_player_iface_proxy_stop_async (MprisPlayerIface* self,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2.Player", "Stop");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_stop_finish (MprisPlayerIface* self,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_player_iface_proxy_play_async (MprisPlayerIface* self,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2.Player", "Play");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_play_finish (MprisPlayerIface* self,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_player_iface_proxy_seek_async (MprisPlayerIface* self,
                                     gint64 offset,
                                     GAsyncReadyCallback _callback_,
                                     gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2.Player", "Seek");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_int64 (offset));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_seek_finish (MprisPlayerIface* self,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
mpris_player_iface_proxy_open_uri_async (MprisPlayerIface* self,
                                         const gchar* uri,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.mpris.MediaPlayer2.Player", "OpenUri");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (uri));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	if (_callback_ != NULL) {
		g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_task_new ((GObject *) self, NULL, _callback_, _user_data_));
	} else {
		g_dbus_message_set_flags (_message, G_DBUS_MESSAGE_FLAGS_NO_REPLY_EXPECTED);
		g_dbus_connection_send_message (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	}
	g_object_unref (_message);
}

static void
mpris_player_iface_proxy_open_uri_finish (MprisPlayerIface* self,
                                          GAsyncResult* _res_,
                                          GError** error)
{
	GAsyncResult *_inner_res;
	GDBusMessage *_reply_message;
	_inner_res = g_task_propagate_pointer ((GTask *) _res_, NULL);
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), _inner_res, error);
	g_object_unref (_inner_res);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static gchar*
mpris_player_iface_dbus_proxy_get_playback_status (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "PlaybackStatus");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("PlaybackStatus"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static gchar*
mpris_player_iface_dbus_proxy_get_loop_status (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gchar* _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "LoopStatus");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("LoopStatus"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_dup_string (_inner_reply, NULL);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_player_iface_dbus_proxy_set_loop_status (MprisPlayerIface* self,
                                               const gchar* value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("LoopStatus"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static gdouble
mpris_player_iface_dbus_proxy_get_rate (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gdouble _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Rate");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Rate"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gdouble _tmp56_ = 0.0;
			return _tmp56_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_double (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_player_iface_dbus_proxy_set_rate (MprisPlayerIface* self,
                                        gdouble value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Rate"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_double (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static gboolean
mpris_player_iface_dbus_proxy_get_shuffle (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Shuffle");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Shuffle"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp57_ = FALSE;
			return _tmp57_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_player_iface_dbus_proxy_set_shuffle (MprisPlayerIface* self,
                                           gboolean value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Shuffle"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static GHashTable*
mpris_player_iface_dbus_proxy_get_metadata (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	GHashTable* _result;
	GHashTable* _tmp58_;
	GVariantIter _tmp59_;
	GVariant* _tmp60_;
	GVariant* _tmp61_;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Metadata");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Metadata"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			return NULL;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_tmp58_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_variant_unref);
	g_variant_iter_init (&_tmp59_, _inner_reply);
	while (g_variant_iter_loop (&_tmp59_, "{?*}", &_tmp60_, &_tmp61_)) {
		g_hash_table_insert (_tmp58_, g_variant_dup_string (_tmp60_, NULL), g_variant_get_variant (_tmp61_));
	}
	_result = _tmp58_;
	g_variant_unref (_inner_reply);
	return _result;
}

static gdouble
mpris_player_iface_dbus_proxy_get_volume (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gdouble _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Volume");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Volume"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gdouble _tmp62_ = 0.0;
			return _tmp62_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_double (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_player_iface_dbus_proxy_set_volume (MprisPlayerIface* self,
                                          gdouble value)
{
	GVariant *_arguments;
	GVariant *_reply;
	GVariantBuilder _arguments_builder;
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Volume"));
	g_variant_builder_open (&_arguments_builder, G_VARIANT_TYPE_VARIANT);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_double (value));
	g_variant_builder_close (&_arguments_builder);
	_arguments = g_variant_builder_end (&_arguments_builder);
	_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Set", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
	if (!_reply) {
		return;
	}
	g_variant_unref (_reply);
}

static gint64
mpris_player_iface_dbus_proxy_get_position (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gint64 _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Position");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Position"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gint64 _tmp63_ = 0LL;
			return _tmp63_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_int64 (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gdouble
mpris_player_iface_dbus_proxy_get_minimum_rate (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gdouble _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "MinimumRate");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("MinimumRate"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gdouble _tmp64_ = 0.0;
			return _tmp64_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_double (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gdouble
mpris_player_iface_dbus_proxy_get_maximum_rate (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gdouble _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "MaximumRate");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("MaximumRate"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gdouble _tmp65_ = 0.0;
			return _tmp65_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_double (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_go_next (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanGoNext");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanGoNext"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp66_ = FALSE;
			return _tmp66_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_go_previous (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanGoPrevious");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanGoPrevious"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp67_ = FALSE;
			return _tmp67_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_play (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanPlay");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanPlay"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp68_ = FALSE;
			return _tmp68_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_pause (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanPause");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanPause"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp69_ = FALSE;
			return _tmp69_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_seek (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanSeek");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanSeek"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp70_ = FALSE;
			return _tmp70_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static gboolean
mpris_player_iface_dbus_proxy_get_can_control (MprisPlayerIface* self)
{
	GVariant *_inner_reply;
	gboolean _result;
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "CanControl");
	if (!_inner_reply) {
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.mpris.MediaPlayer2.Player"));
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("CanControl"));
		_arguments = g_variant_builder_end (&_arguments_builder);
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
		if (!_reply) {
			gboolean _tmp71_ = FALSE;
			return _tmp71_;
		}
		g_variant_get (_reply, "(v)", &_inner_reply);
		g_variant_unref (_reply);
	}
	_result = g_variant_get_boolean (_inner_reply);
	g_variant_unref (_inner_reply);
	return _result;
}

static void
mpris_player_iface_proxy_mpris_player_iface_interface_init (MprisPlayerIfaceIface* iface)
{
	iface->next = mpris_player_iface_proxy_next_async;
	iface->next_finish = mpris_player_iface_proxy_next_finish;
	iface->previous = mpris_player_iface_proxy_previous_async;
	iface->previous_finish = mpris_player_iface_proxy_previous_finish;
	iface->pause = mpris_player_iface_proxy_pause_async;
	iface->pause_finish = mpris_player_iface_proxy_pause_finish;
	iface->play_pause = mpris_player_iface_proxy_play_pause_async;
	iface->play_pause_finish = mpris_player_iface_proxy_play_pause_finish;
	iface->stop = mpris_player_iface_proxy_stop_async;
	iface->stop_finish = mpris_player_iface_proxy_stop_finish;
	iface->play = mpris_player_iface_proxy_play_async;
	iface->play_finish = mpris_player_iface_proxy_play_finish;
	iface->seek = mpris_player_iface_proxy_seek_async;
	iface->seek_finish = mpris_player_iface_proxy_seek_finish;
	iface->open_uri = mpris_player_iface_proxy_open_uri_async;
	iface->open_uri_finish = mpris_player_iface_proxy_open_uri_finish;
	iface->get_playback_status = mpris_player_iface_dbus_proxy_get_playback_status;
	iface->get_loop_status = mpris_player_iface_dbus_proxy_get_loop_status;
	iface->set_loop_status = mpris_player_iface_dbus_proxy_set_loop_status;
	iface->get_rate = mpris_player_iface_dbus_proxy_get_rate;
	iface->set_rate = mpris_player_iface_dbus_proxy_set_rate;
	iface->get_shuffle = mpris_player_iface_dbus_proxy_get_shuffle;
	iface->set_shuffle = mpris_player_iface_dbus_proxy_set_shuffle;
	iface->get_metadata = mpris_player_iface_dbus_proxy_get_metadata;
	iface->get_volume = mpris_player_iface_dbus_proxy_get_volume;
	iface->set_volume = mpris_player_iface_dbus_proxy_set_volume;
	iface->get_position = mpris_player_iface_dbus_proxy_get_position;
	iface->get_minimum_rate = mpris_player_iface_dbus_proxy_get_minimum_rate;
	iface->get_maximum_rate = mpris_player_iface_dbus_proxy_get_maximum_rate;
	iface->get_can_go_next = mpris_player_iface_dbus_proxy_get_can_go_next;
	iface->get_can_go_previous = mpris_player_iface_dbus_proxy_get_can_go_previous;
	iface->get_can_play = mpris_player_iface_dbus_proxy_get_can_play;
	iface->get_can_pause = mpris_player_iface_dbus_proxy_get_can_pause;
	iface->get_can_seek = mpris_player_iface_dbus_proxy_get_can_seek;
	iface->get_can_control = mpris_player_iface_dbus_proxy_get_can_control;
}

static void
_dbus_mpris_player_iface_next (MprisPlayerIface* self,
                               GVariant* _parameters_,
                               GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisPlayerIfaceNextReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisPlayerIfaceNextReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_player_iface_next (self, (GAsyncReadyCallback) _dbus_mpris_player_iface_next_ready, _ready_data);
}

static void
_dbus_mpris_player_iface_next_ready (GObject * source_object,
                                     GAsyncResult * _res_,
                                     gpointer _user_data_)
{
	MprisPlayerIfaceNextReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_player_iface_next_finish ((MprisPlayerIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisPlayerIfaceNextReadyData, _ready_data);
}

static void
_dbus_mpris_player_iface_previous (MprisPlayerIface* self,
                                   GVariant* _parameters_,
                                   GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisPlayerIfacePreviousReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisPlayerIfacePreviousReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_player_iface_previous (self, (GAsyncReadyCallback) _dbus_mpris_player_iface_previous_ready, _ready_data);
}

static void
_dbus_mpris_player_iface_previous_ready (GObject * source_object,
                                         GAsyncResult * _res_,
                                         gpointer _user_data_)
{
	MprisPlayerIfacePreviousReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_player_iface_previous_finish ((MprisPlayerIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisPlayerIfacePreviousReadyData, _ready_data);
}

static void
_dbus_mpris_player_iface_pause (MprisPlayerIface* self,
                                GVariant* _parameters_,
                                GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisPlayerIfacePauseReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisPlayerIfacePauseReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_player_iface_pause (self, (GAsyncReadyCallback) _dbus_mpris_player_iface_pause_ready, _ready_data);
}

static void
_dbus_mpris_player_iface_pause_ready (GObject * source_object,
                                      GAsyncResult * _res_,
                                      gpointer _user_data_)
{
	MprisPlayerIfacePauseReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_player_iface_pause_finish ((MprisPlayerIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisPlayerIfacePauseReadyData, _ready_data);
}

static void
_dbus_mpris_player_iface_play_pause (MprisPlayerIface* self,
                                     GVariant* _parameters_,
                                     GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisPlayerIfacePlayPauseReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisPlayerIfacePlayPauseReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_player_iface_play_pause (self, (GAsyncReadyCallback) _dbus_mpris_player_iface_play_pause_ready, _ready_data);
}

static void
_dbus_mpris_player_iface_play_pause_ready (GObject * source_object,
                                           GAsyncResult * _res_,
                                           gpointer _user_data_)
{
	MprisPlayerIfacePlayPauseReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_player_iface_play_pause_finish ((MprisPlayerIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisPlayerIfacePlayPauseReadyData, _ready_data);
}

static void
_dbus_mpris_player_iface_stop (MprisPlayerIface* self,
                               GVariant* _parameters_,
                               GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisPlayerIfaceStopReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisPlayerIfaceStopReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_player_iface_stop (self, (GAsyncReadyCallback) _dbus_mpris_player_iface_stop_ready, _ready_data);
}

static void
_dbus_mpris_player_iface_stop_ready (GObject * source_object,
                                     GAsyncResult * _res_,
                                     gpointer _user_data_)
{
	MprisPlayerIfaceStopReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_player_iface_stop_finish ((MprisPlayerIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisPlayerIfaceStopReadyData, _ready_data);
}

static void
_dbus_mpris_player_iface_play (MprisPlayerIface* self,
                               GVariant* _parameters_,
                               GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisPlayerIfacePlayReadyData* _ready_data;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisPlayerIfacePlayReadyData);
	_ready_data->_invocation_ = invocation;
	mpris_player_iface_play (self, (GAsyncReadyCallback) _dbus_mpris_player_iface_play_ready, _ready_data);
}

static void
_dbus_mpris_player_iface_play_ready (GObject * source_object,
                                     GAsyncResult * _res_,
                                     gpointer _user_data_)
{
	MprisPlayerIfacePlayReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_player_iface_play_finish ((MprisPlayerIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisPlayerIfacePlayReadyData, _ready_data);
}

static void
_dbus_mpris_player_iface_seek (MprisPlayerIface* self,
                               GVariant* _parameters_,
                               GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisPlayerIfaceSeekReadyData* _ready_data;
	GVariant* _tmp72_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisPlayerIfaceSeekReadyData);
	_ready_data->_invocation_ = invocation;
	_tmp72_ = g_variant_iter_next_value (&_arguments_iter);
	_ready_data->offset = g_variant_get_int64 (_tmp72_);
	g_variant_unref (_tmp72_);
	mpris_player_iface_seek (self, _ready_data->offset, (GAsyncReadyCallback) _dbus_mpris_player_iface_seek_ready, _ready_data);
}

static void
_dbus_mpris_player_iface_seek_ready (GObject * source_object,
                                     GAsyncResult * _res_,
                                     gpointer _user_data_)
{
	MprisPlayerIfaceSeekReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_player_iface_seek_finish ((MprisPlayerIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	g_slice_free (MprisPlayerIfaceSeekReadyData, _ready_data);
}

static void
_dbus_mpris_player_iface_open_uri (MprisPlayerIface* self,
                                   GVariant* _parameters_,
                                   GDBusMethodInvocation* invocation)
{
	GVariantIter _arguments_iter;
	MprisPlayerIfaceOpenUriReadyData* _ready_data;
	GVariant* _tmp73_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_ready_data = g_slice_new0 (MprisPlayerIfaceOpenUriReadyData);
	_ready_data->_invocation_ = invocation;
	_tmp73_ = g_variant_iter_next_value (&_arguments_iter);
	_ready_data->uri = g_variant_dup_string (_tmp73_, NULL);
	g_variant_unref (_tmp73_);
	mpris_player_iface_open_uri (self, _ready_data->uri, (GAsyncReadyCallback) _dbus_mpris_player_iface_open_uri_ready, _ready_data);
	_error:
	;
}

static void
_dbus_mpris_player_iface_open_uri_ready (GObject * source_object,
                                         GAsyncResult * _res_,
                                         gpointer _user_data_)
{
	MprisPlayerIfaceOpenUriReadyData* _ready_data;
	GDBusMethodInvocation* invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	_ready_data = _user_data_;
	invocation = _ready_data->_invocation_;
	mpris_player_iface_open_uri_finish ((MprisPlayerIface*) source_object, _res_, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	_g_free0 (_ready_data->uri);
	g_slice_free (MprisPlayerIfaceOpenUriReadyData, _ready_data);
}

static void
mpris_player_iface_dbus_interface_method_call (GDBusConnection* connection,
                                               const gchar* sender,
                                               const gchar* object_path,
                                               const gchar* interface_name,
                                               const gchar* method_name,
                                               GVariant* parameters,
                                               GDBusMethodInvocation* invocation,
                                               gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "Next") == 0) {
		_dbus_mpris_player_iface_next (object, parameters, invocation);
	} else if (strcmp (method_name, "Previous") == 0) {
		_dbus_mpris_player_iface_previous (object, parameters, invocation);
	} else if (strcmp (method_name, "Pause") == 0) {
		_dbus_mpris_player_iface_pause (object, parameters, invocation);
	} else if (strcmp (method_name, "PlayPause") == 0) {
		_dbus_mpris_player_iface_play_pause (object, parameters, invocation);
	} else if (strcmp (method_name, "Stop") == 0) {
		_dbus_mpris_player_iface_stop (object, parameters, invocation);
	} else if (strcmp (method_name, "Play") == 0) {
		_dbus_mpris_player_iface_play (object, parameters, invocation);
	} else if (strcmp (method_name, "Seek") == 0) {
		_dbus_mpris_player_iface_seek (object, parameters, invocation);
	} else if (strcmp (method_name, "OpenUri") == 0) {
		_dbus_mpris_player_iface_open_uri (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
_dbus_mpris_player_iface_get_playback_status (MprisPlayerIface* self)
{
	gchar* result;
	GVariant* _reply;
	result = mpris_player_iface_get_playback_status (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_loop_status (MprisPlayerIface* self)
{
	gchar* result;
	GVariant* _reply;
	result = mpris_player_iface_get_loop_status (self);
	_reply = g_variant_new_string (result);
	_g_free0 (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_rate (MprisPlayerIface* self)
{
	gdouble result;
	GVariant* _reply;
	result = mpris_player_iface_get_rate (self);
	_reply = g_variant_new_double (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_shuffle (MprisPlayerIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_player_iface_get_shuffle (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_metadata (MprisPlayerIface* self)
{
	GHashTable* result;
	GVariant* _reply;
	GVariantBuilder _tmp74_;
	GHashTableIter _tmp75_;
	gpointer _tmp76_;
	gpointer _tmp77_;
	result = mpris_player_iface_get_metadata (self);
	g_hash_table_iter_init (&_tmp75_, result);
	g_variant_builder_init (&_tmp74_, G_VARIANT_TYPE ("a{sv}"));
	while (g_hash_table_iter_next (&_tmp75_, &_tmp76_, &_tmp77_)) {
		gchar* _key;
		GVariant* _value;
		_key = (gchar*) _tmp76_;
		_value = (GVariant*) _tmp77_;
		g_variant_builder_add (&_tmp74_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
	}
	_reply = g_variant_builder_end (&_tmp74_);
	_g_hash_table_unref0 (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_volume (MprisPlayerIface* self)
{
	gdouble result;
	GVariant* _reply;
	result = mpris_player_iface_get_volume (self);
	_reply = g_variant_new_double (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_position (MprisPlayerIface* self)
{
	gint64 result;
	GVariant* _reply;
	result = mpris_player_iface_get_position (self);
	_reply = g_variant_new_int64 (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_minimum_rate (MprisPlayerIface* self)
{
	gdouble result;
	GVariant* _reply;
	result = mpris_player_iface_get_minimum_rate (self);
	_reply = g_variant_new_double (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_maximum_rate (MprisPlayerIface* self)
{
	gdouble result;
	GVariant* _reply;
	result = mpris_player_iface_get_maximum_rate (self);
	_reply = g_variant_new_double (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_can_go_next (MprisPlayerIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_player_iface_get_can_go_next (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_can_go_previous (MprisPlayerIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_player_iface_get_can_go_previous (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_can_play (MprisPlayerIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_player_iface_get_can_play (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_can_pause (MprisPlayerIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_player_iface_get_can_pause (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_can_seek (MprisPlayerIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_player_iface_get_can_seek (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
_dbus_mpris_player_iface_get_can_control (MprisPlayerIface* self)
{
	gboolean result;
	GVariant* _reply;
	result = mpris_player_iface_get_can_control (self);
	_reply = g_variant_new_boolean (result);
	return _reply;
}

static GVariant*
mpris_player_iface_dbus_interface_get_property (GDBusConnection* connection,
                                                const gchar* sender,
                                                const gchar* object_path,
                                                const gchar* interface_name,
                                                const gchar* property_name,
                                                GError** error,
                                                gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "PlaybackStatus") == 0) {
		return _dbus_mpris_player_iface_get_playback_status (object);
	} else if (strcmp (property_name, "LoopStatus") == 0) {
		return _dbus_mpris_player_iface_get_loop_status (object);
	} else if (strcmp (property_name, "Rate") == 0) {
		return _dbus_mpris_player_iface_get_rate (object);
	} else if (strcmp (property_name, "Shuffle") == 0) {
		return _dbus_mpris_player_iface_get_shuffle (object);
	} else if (strcmp (property_name, "Metadata") == 0) {
		return _dbus_mpris_player_iface_get_metadata (object);
	} else if (strcmp (property_name, "Volume") == 0) {
		return _dbus_mpris_player_iface_get_volume (object);
	} else if (strcmp (property_name, "Position") == 0) {
		return _dbus_mpris_player_iface_get_position (object);
	} else if (strcmp (property_name, "MinimumRate") == 0) {
		return _dbus_mpris_player_iface_get_minimum_rate (object);
	} else if (strcmp (property_name, "MaximumRate") == 0) {
		return _dbus_mpris_player_iface_get_maximum_rate (object);
	} else if (strcmp (property_name, "CanGoNext") == 0) {
		return _dbus_mpris_player_iface_get_can_go_next (object);
	} else if (strcmp (property_name, "CanGoPrevious") == 0) {
		return _dbus_mpris_player_iface_get_can_go_previous (object);
	} else if (strcmp (property_name, "CanPlay") == 0) {
		return _dbus_mpris_player_iface_get_can_play (object);
	} else if (strcmp (property_name, "CanPause") == 0) {
		return _dbus_mpris_player_iface_get_can_pause (object);
	} else if (strcmp (property_name, "CanSeek") == 0) {
		return _dbus_mpris_player_iface_get_can_seek (object);
	} else if (strcmp (property_name, "CanControl") == 0) {
		return _dbus_mpris_player_iface_get_can_control (object);
	}
	return NULL;
}

static void
_dbus_mpris_player_iface_set_loop_status (MprisPlayerIface* self,
                                          GVariant* _value)
{
	gchar* value = NULL;
	value = g_variant_dup_string (_value, NULL);
	mpris_player_iface_set_loop_status (self, value);
	_g_free0 (value);
}

static void
_dbus_mpris_player_iface_set_rate (MprisPlayerIface* self,
                                   GVariant* _value)
{
	gdouble value = 0.0;
	value = g_variant_get_double (_value);
	mpris_player_iface_set_rate (self, value);
}

static void
_dbus_mpris_player_iface_set_shuffle (MprisPlayerIface* self,
                                      GVariant* _value)
{
	gboolean value = FALSE;
	value = g_variant_get_boolean (_value);
	mpris_player_iface_set_shuffle (self, value);
}

static void
_dbus_mpris_player_iface_set_volume (MprisPlayerIface* self,
                                     GVariant* _value)
{
	gdouble value = 0.0;
	value = g_variant_get_double (_value);
	mpris_player_iface_set_volume (self, value);
}

static gboolean
mpris_player_iface_dbus_interface_set_property (GDBusConnection* connection,
                                                const gchar* sender,
                                                const gchar* object_path,
                                                const gchar* interface_name,
                                                const gchar* property_name,
                                                GVariant* value,
                                                GError** error,
                                                gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (property_name, "LoopStatus") == 0) {
		_dbus_mpris_player_iface_set_loop_status (object, value);
		return TRUE;
	} else if (strcmp (property_name, "Rate") == 0) {
		_dbus_mpris_player_iface_set_rate (object, value);
		return TRUE;
	} else if (strcmp (property_name, "Shuffle") == 0) {
		_dbus_mpris_player_iface_set_shuffle (object, value);
		return TRUE;
	} else if (strcmp (property_name, "Volume") == 0) {
		_dbus_mpris_player_iface_set_volume (object, value);
		return TRUE;
	}
	return FALSE;
}

guint
mpris_player_iface_register_object (gpointer object,
                                    GDBusConnection* connection,
                                    const gchar* path,
                                    GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_mpris_player_iface_dbus_interface_info), &_mpris_player_iface_dbus_interface_vtable, data, _mpris_player_iface_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}

static void
_mpris_player_iface_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

static void
new_iface_data_free (gpointer _data)
{
	NewIfaceData* _data_;
	_data_ = _data;
	_g_free0 (_data_->busname);
	_g_object_unref0 (_data_->result);
	g_slice_free (NewIfaceData, _data_);
}

void
new_iface (const gchar* busname,
           GAsyncReadyCallback _callback_,
           gpointer _user_data_)
{
	NewIfaceData* _data_;
	gchar* _tmp0_;
	g_return_if_fail (busname != NULL);
	_data_ = g_slice_new0 (NewIfaceData);
	_data_->_async_result = g_task_new (NULL, NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, new_iface_data_free);
	_tmp0_ = g_strdup (busname);
	_g_free0 (_data_->busname);
	_data_->busname = _tmp0_;
	new_iface_co (_data_);
}

MprisClient*
new_iface_finish (GAsyncResult* _res_)
{
	MprisClient* result;
	NewIfaceData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
	result = _data_->result;
	_data_->result = NULL;
	return result;
}

/**
 * Utility function, return a new iface instance, i.e. deal
 * with all the dbus cruft
 *
 * @param busname The busname to instaniate ifaces from
 * @return a new MprisClient, or null if errors occurred.
 */
static void
new_iface_ready (GObject* source_object,
                 GAsyncResult* _res_,
                 gpointer _user_data_)
{
	NewIfaceData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	new_iface_co (_data_);
}

static gboolean
new_iface_co (NewIfaceData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->play = NULL;
	_data_->cl = NULL;
	_data_->prop = NULL;
	{
		_data_->_state_ = 1;
		g_async_initable_new_async (TYPE_MPRIS_PLAYER_IFACE_PROXY, 0, NULL, new_iface_ready, _data_, "g-flags", 0, "g-name", _data_->busname, "g-bus-type", G_BUS_TYPE_SESSION, "g-object-path", "/org/mpris/MediaPlayer2", "g-interface-name", "org.mpris.MediaPlayer2.Player", NULL);
		return FALSE;
		_state_1:
		_data_->_tmp1_ = (MprisPlayerIface*) g_async_initable_new_finish ((GAsyncInitable *) _data_->_source_object_, _data_->_res_, &_data_->_inner_error0_);
		_data_->_tmp0_ = (MprisPlayerIface*) _data_->_tmp1_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp2_ = _data_->_tmp0_;
		_data_->_tmp0_ = NULL;
		_g_object_unref0 (_data_->play);
		_data_->play = _data_->_tmp2_;
		_g_object_unref0 (_data_->_tmp0_);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp3_ = _data_->e;
		_data_->_tmp4_ = _data_->_tmp3_->message;
		g_message ("mpris_client.vala:114: %s", _data_->_tmp4_);
		_data_->result = NULL;
		_g_error_free0 (_data_->e);
		_g_object_unref0 (_data_->prop);
		_g_object_unref0 (_data_->cl);
		_g_object_unref0 (_data_->play);
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
		if (_data_->_state_ != 0) {
			while (!g_task_get_completed (_data_->_async_result)) {
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
			}
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_object_unref0 (_data_->prop);
		_g_object_unref0 (_data_->cl);
		_g_object_unref0 (_data_->play);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	{
		_data_->_state_ = 2;
		g_async_initable_new_async (TYPE_MPRIS_DBUS_PROP_IFACE_PROXY, 0, NULL, new_iface_ready, _data_, "g-flags", 0, "g-name", _data_->busname, "g-bus-type", G_BUS_TYPE_SESSION, "g-object-path", "/org/mpris/MediaPlayer2", "g-interface-name", "org.freedesktop.DBus.Properties", NULL);
		return FALSE;
		_state_2:
		_data_->_tmp6_ = (MprisDbusPropIface*) g_async_initable_new_finish ((GAsyncInitable *) _data_->_source_object_, _data_->_res_, &_data_->_inner_error0_);
		_data_->_tmp5_ = (MprisDbusPropIface*) _data_->_tmp6_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch1_g_error;
		}
		_data_->_tmp7_ = _data_->_tmp5_;
		_data_->_tmp5_ = NULL;
		_g_object_unref0 (_data_->prop);
		_data_->prop = _data_->_tmp7_;
		_g_object_unref0 (_data_->_tmp5_);
	}
	goto __finally1;
	__catch1_g_error:
	{
		_data_->_vala1_e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp8_ = _data_->_vala1_e;
		_data_->_tmp9_ = _data_->_tmp8_->message;
		g_message ("mpris_client.vala:120: %s", _data_->_tmp9_);
		_data_->result = NULL;
		_g_error_free0 (_data_->_vala1_e);
		_g_object_unref0 (_data_->prop);
		_g_object_unref0 (_data_->cl);
		_g_object_unref0 (_data_->play);
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
		if (_data_->_state_ != 0) {
			while (!g_task_get_completed (_data_->_async_result)) {
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
			}
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	__finally1:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_object_unref0 (_data_->prop);
		_g_object_unref0 (_data_->cl);
		_g_object_unref0 (_data_->play);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp10_ = _data_->play;
	_data_->_tmp11_ = _data_->prop;
	_data_->_tmp12_ = mpris_client_new (_data_->_tmp10_, _data_->_tmp11_);
	_g_object_unref0 (_data_->cl);
	_data_->cl = _data_->_tmp12_;
	_data_->result = _data_->cl;
	_g_object_unref0 (_data_->prop);
	_g_object_unref0 (_data_->play);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

